(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    122001,       2935]
NotebookOptionsPosition[     67876,       1903]
NotebookOutlinePosition[    105043,       2708]
CellTagsIndexPosition[    104963,       2703]
WindowTitle->Statistics: Model Fitting
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["", "SlideShowNavigationBar",
 CellTags->
  "SlideShowHeader",ExpressionUUID->"40b2505a-7ad7-41c6-8278-7a767f68d928"],

Cell["Statistics: Model Fitting", "Title",
 CellChangeTimes->{{3.520677779770745*^9, 3.5206777856383314`*^9}, {
  3.5372020290709085`*^9, 3.53720203957388*^9}, {3.53769758402109*^9, 
  3.537697599182867*^9}, {3.537729558380665*^9, 
  3.537729568598708*^9}},ExpressionUUID->"f071160a-c4b0-4a33-b851-\
ed9a2e790b08"],

Cell["\<\
Darren Glosemeyer & Harry Calkins
Wolfram Research
training@wolfram.com\
\>", "Subsubtitle",
 CellChangeTimes->{{3.520677813734141*^9, 3.520677823088076*^9}, {
  3.520687372999189*^9, 3.520687386262189*^9}, {3.5372020548140244`*^9, 
  3.537202058741335*^9}, {3.537202120722994*^9, 3.5372021251081343`*^9}, {
  3.537202351154377*^9, 
  3.537202382539572*^9}},ExpressionUUID->"a541018f-0547-4229-ad63-\
bec7c491a576"],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.53720481777791*^9, 
  3.5372048204431763`*^9}},ExpressionUUID->"f9f913ca-4c93-481d-ae7e-\
a7589c336be0"]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->
  "SlideShowHeader",ExpressionUUID->"5c7ca38e-9c31-48e8-8d24-f55be1c18e26"],

Cell[CellGroupData[{

Cell["Model Fitting and Analysis", "Section",ExpressionUUID->"44aab477-e371-4e06-8dc5-de4dbcc9a941"],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " includes a framework and functionality for linear and nonlinear \
regression, logit, probit, and generalized linear models. An extensive set of \
optimization functions, linear algebra functions, and a package for analysis \
of variance (ANOVA) all provide capabilities of interest in model fitting and \
analysis."
}], "Text",ExpressionUUID->"53bdaf84-c24f-4571-98f6-ac64c1002967"],

Cell["", "Spacer",ExpressionUUID->"4d7c7fdc-c1ee-46bd-87da-4c26a881e685"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->
  "SlideShowHeader",ExpressionUUID->"c0d3b38b-c7b2-4f5f-b5d5-91cdafc94a3d"],

Cell[CellGroupData[{

Cell["Model Fitting and Analysis: Linear Regression", "Section",
 CellChangeTimes->{
  3.537697639482026*^9},ExpressionUUID->"d03d22c7-310b-4ac4-915d-\
286824303c5f"],

Cell["Here we import some data from an Excel spreadsheet.", "Text",ExpressionUUID->"ef311bae-dd47-4972-8d3c-88a918fadbec"],

Cell[BoxData[
 RowBox[{"lineardata", "=", 
  RowBox[{"Import", "[", 
   RowBox[{"\"\<linearfitdata.xls\>\"", ",", 
    RowBox[{"{", 
     RowBox[{"\"\<Data\>\"", ",", "1"}], "}"}]}], "]"}]}]], "Input",
 PageWidth->
  WindowWidth,ExpressionUUID->"f00961f3-3a06-4827-a893-845feca519f0"],

Cell[TextData[{
 "The data can be fitted to a linear model using ",
 Cell[BoxData[
  ButtonBox["LinearModelFit",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/LinearModelFit"]], "InlineFormula",ExpressionUUID->
  "e73a33d9-4a72-41ac-98e8-803a6ad53ce6"],
 "."
}], "MathCaption",
 CellChangeTimes->{{3.434112033393976*^9, 
  3.434112038865075*^9}},ExpressionUUID->"63a8f2fc-19e4-4666-9573-\
599d1d7146eb"],

Cell[BoxData[
 RowBox[{"lm", "=", 
  RowBox[{"LinearModelFit", "[", 
   RowBox[{"lineardata", ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}]}]], "Input",
 PageWidth->WindowWidth,
 CellChangeTimes->{{3.434112048756946*^9, 3.4341120565795193`*^9}, {
   3.4341121136106267`*^9, 3.434112114237687*^9}, 3.4341138585746155`*^9, 
   3.438088489327569*^9},ExpressionUUID->"b62e4533-40cc-4a83-a010-\
d7278e660aa1"],

Cell[BoxData[
 RowBox[{"Normal", "[", "lm", "]"}]], "Input",
 CellChangeTimes->{{3.442051101928609*^9, 
  3.442051105915276*^9}},ExpressionUUID->"7d4c3927-97d5-4d41-8ee7-\
a3c21b09b2e1"],

Cell["", "Spacer",ExpressionUUID->"c6a7486a-7a54-4c65-8afd-f512d8918466"],

Cell[TextData[{
 Cell[BoxData[
  ButtonBox["LinearModelFit",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/LinearModelFit"]], "InlineFormula",ExpressionUUID->
  "562cd258-0ead-48fe-b9cc-b8a06009e542"],
 " produces a ",
 Cell[BoxData[
  ButtonBox["FittedModel",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/FittedModel"]], "InlineFormula",ExpressionUUID->
  "c64e98f2-a16a-4d44-9268-1f554f1648fd"],
 " object that can be evaluated at a point and from which diagnostics and \
results can be obtained.  "
}], "Text",ExpressionUUID->"b52ef9f3-7122-476f-bac8-5d82417bb256"],

Cell[TextData[{
 "This gives the predicted value for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", "y", ",", "z"}], "}"}], "=", 
    RowBox[{"{", 
     RowBox[{"1", ",", "3", ",", "5"}], "}"}]}], TraditionalForm]],
  ExpressionUUID->"d51cb88f-bb9e-4516-ac68-6c2714941e11"],
 "."
}], "MathCaption",ExpressionUUID->"757fa8e3-b6ce-4685-bab9-1f2b767478a3"],

Cell[BoxData[
 RowBox[{"lm", "[", 
  RowBox[{"1", ",", "3", ",", "5"}], "]"}]], "Input",
 CellChangeTimes->{{3.4976267989628434`*^9, 
  3.497626827167593*^9}},ExpressionUUID->"e333d078-20c9-4349-a5b5-\
e35e4f3cfd20"],

Cell[TextData[{
 "A list of available results can be obtained by asking for the ",
 StyleBox["\"Properties\"", "MR"],
 " of the model",
 "."
}], "MathCaption",
 CellChangeTimes->{
  3.5364947223524895`*^9},ExpressionUUID->"a2a26c37-2e42-4781-9a47-\
15544d5224f0"],

Cell[BoxData[
 RowBox[{"lm", "[", "\"\<Properties\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.4341121810352535`*^9, 
  3.4341121858479385`*^9}},ExpressionUUID->"10c75552-4c0c-44d0-93a2-\
e881518f0adb"],

Cell["", "Spacer",ExpressionUUID->"bd3d3f94-8845-4a4d-ac6d-a448727ff117"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->
  "SlideShowHeader",ExpressionUUID->"6a5e94c0-3a2c-4ff2-b50d-126326259235"],

Cell[CellGroupData[{

Cell["Model Fitting and Analysis: Linear Regression Diagnostics", "Section",
 CellChangeTimes->{{3.537697653905508*^9, 
  3.537697658631572*^9}},ExpressionUUID->"ad7c115b-a7d1-47b1-91f6-\
7bdca7f5b2a9"],

Cell["\<\
Individual properties or lists of properties can be obtained in the same \
manner.\
\>", "Text",
 CellChangeTimes->{{3.434112227806865*^9, 
  3.434112247423827*^9}},ExpressionUUID->"0e73eb03-8ace-4de8-99af-\
e41053f45e6f"],

Cell["\<\
Here the standardized residuals and Cook\[CloseCurlyQuote]s distances are \
extracted.\
\>", "MathCaption",ExpressionUUID->"642398d9-7635-4929-b55b-3537cf26ff4a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"stresids", ",", "cookd"}], "}"}], "=", 
  RowBox[{"lm", "[", 
   RowBox[{"{", 
    RowBox[{"\"\<StandardizedResiduals\>\"", ",", "\"\<CookDistances\>\""}], 
    "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4341122527667856`*^9, 
  3.434112266351375*^9}},ExpressionUUID->"57720251-e7e2-452d-89f8-\
bf02dd34bcca"],

Cell["\<\
In a linear regression, we might wish to look at plots of the standardized \
residuals and Cook\[CloseCurlyQuote]s distances to assess approximate \
normality of errors and influence of individual points.\
\>", "MathCaption",
 CellChangeTimes->{{3.434112591172591*^9, 3.4341125913606005`*^9}, {
  3.434113067409542*^9, 
  3.4341130689603176`*^9}},ExpressionUUID->"b320d315-6cb4-4746-a255-\
7b0e30ece406"],

Cell[BoxData[
 RowBox[{"GraphicsRow", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"QuantilePlot", "[", "stresids", "]"}], ",", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"cookd", ",", 
       RowBox[{"Filling", "\[Rule]", "Bottom"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", " ", "Large"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.43534243542308*^9, 3.43534243996564*^9}, {
  3.4353424753349524`*^9, 3.4353424894795437`*^9}, {3.4354995274510136`*^9, 
  3.4354995511115456`*^9}, {3.442051172081203*^9, 3.44205119481553*^9}, {
  3.442138105616831*^9, 3.442138114452799*^9}, {3.5322660919284596`*^9, 
  3.532266093110578*^9}},ExpressionUUID->"3c001d22-c88d-49e7-9210-\
4d18d379a4b8"],

Cell["\<\
Residuals can also be viewed against predictors to check for systematic \
trends that would violate the model assumptions.\
\>", "MathCaption",
 CellChangeTimes->{{3.4355120984917855`*^9, 3.4355121850098476`*^9}, {
  3.537697684698234*^9, 
  3.5376976853035383`*^9}},ExpressionUUID->"6ac50df3-06da-4643-a262-\
cd60153cd666"],

Cell[BoxData[
 RowBox[{"GraphicsRow", "[", 
  RowBox[{
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"resids", "=", 
       RowBox[{"lm", "[", "\"\<FitResiduals\>\"", "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"ListPlot", "[", 
        RowBox[{
         RowBox[{"Transpose", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"lineardata", "[", 
             RowBox[{"[", 
              RowBox[{"All", ",", "i"}], "]"}], "]"}], ",", "resids"}], "}"}],
           "]"}], ",", 
         RowBox[{"Frame", "\[Rule]", "True"}], ",", 
         RowBox[{"FrameLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"{", 
              RowBox[{"x", ",", "y", ",", "z"}], "}"}], "[", 
             RowBox[{"[", "i", "]"}], "]"}], ",", "\"\<residual\>\""}], 
           "}"}]}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}], "]"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", " ", "Large"}]}], "]"}]], "Input",Expressio\
nUUID->"900e72d2-c751-4241-8bd6-f248ac4a2da7"],

Cell["", "Spacer",ExpressionUUID->"1e22c0fb-0ece-4feb-addf-0c84f43580cf"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->
  "SlideShowHeader",ExpressionUUID->"a929462d-4bc3-4e47-ad6f-decc9f054f39"],

Cell[CellGroupData[{

Cell["Model Fitting and Analysis: Generalized Linear Models (GLM)", "Section",
 CellChangeTimes->{{3.537697702393669*^9, 
  3.537697708183236*^9}},ExpressionUUID->"9cb296b3-a4b0-4845-9415-\
b4fedeee3b0c"],

Cell["For linear regression, the model is of the form", "Text",
 CellChangeTimes->{{3.434112612965945*^9, 3.4341126385971403`*^9}, {
   3.434992072481764*^9, 3.434992075638519*^9}, {3.435510526398472*^9, 
   3.4355105683180103`*^9}, 
   3.4355108494225554`*^9},ExpressionUUID->"fb9420ea-8592-4c73-a949-\
56f4a67faf0a"],

Cell[TextData[{
 " ",
 Cell[BoxData[
  RowBox[{
   StyleBox[
    OverscriptBox[
     StyleBox["y", "TI"], "^"], "TI"], "=", 
   RowBox[{
    SubscriptBox[
     StyleBox["\[Beta]", "TR"], 
     StyleBox["0", "TR"]], "+", 
    RowBox[{
     SubscriptBox[
      StyleBox["\[Beta]", "TR"], 
      StyleBox["1", "TR"]], " ", 
     SubscriptBox[
      StyleBox["f", "TI"], 
      StyleBox["1", "TR"]]}], "+", 
    RowBox[{
     SubscriptBox[
      StyleBox["\[Beta]", "TR"], 
      StyleBox["2", "TR"]], " ", 
     SubscriptBox[
      StyleBox["f", "TI"], 
      StyleBox["2", "TR"]]}], "+", 
    StyleBox["\[Ellipsis]", "TR"]}]}]], "InlineFormula",ExpressionUUID->
  "8c3b2c29-697f-4eb3-b3b5-d57467d9ee9e"]
}], "Text",
 CellChangeTimes->{{3.434112612965945*^9, 3.4341126385971403`*^9}, {
  3.434992072481764*^9, 3.434992075638519*^9}, {3.435510526398472*^9, 
  3.4355105812969728`*^9}},
 TextAlignment->-0.5,ExpressionUUID->"78a9b329-f859-4f09-917c-b8c24f643d33"],

Cell[TextData[{
 "for basis functions ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["f", "TI"], 
   StyleBox["1", "TR"]]], "InlineFormula",ExpressionUUID->
  "589e80d7-fb84-4ab0-8cc8-b3d3b2ec4ba8"],
 ", ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["f", "TI"], 
   StyleBox["2", "TR"]]], "InlineFormula",ExpressionUUID->
  "3b66a03a-2059-4a12-acff-199b8e23236d"],
 ", ",
 Cell[BoxData[
  StyleBox["\[Ellipsis]", "TR"]], "InlineFormula",ExpressionUUID->
  "e548f06f-6275-4739-a759-93009ffbe4c7"],
 ". Each observed ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["y", "TI"], 
   StyleBox["i", "TI"]]], "InlineFormula",ExpressionUUID->
  "02e76a6e-f98a-4860-9bd4-e8ab77b62fae"],
 " is assumed to be from a normal distribution with mean ",
 Cell[BoxData[
  StyleBox[
   OverscriptBox[
    StyleBox[
     SubscriptBox[
      StyleBox["y", "TI"], 
      StyleBox["i", "TI"]], "TI"], "^"], "TI"]],ExpressionUUID->
  "a18ceea7-d895-44dc-8911-86c735a372a9"],
 "."
}], "Text",
 CellChangeTimes->{{3.434112612965945*^9, 3.4341126385971403`*^9}, {
  3.434992072481764*^9, 3.434992075638519*^9}, {3.435510526398472*^9, 
  3.4355105742242503`*^9}, {3.435510633109463*^9, 
  3.435510828917861*^9}},ExpressionUUID->"1bbd5019-3320-462d-8188-\
c62ab157c82e"],

Cell["For generalized linear models, the model is of the form", "Text",
 CellChangeTimes->{{3.434112612965945*^9, 3.4341126385971403`*^9}, {
  3.434992072481764*^9, 3.434992075638519*^9}, {3.435510526398472*^9, 
  3.4355105683180103`*^9}, {3.435510839070819*^9, 
  3.435510847725299*^9}},ExpressionUUID->"0b9316da-e24f-4806-b47e-\
54b4813fac7b"],

Cell[TextData[{
 " ",
 Cell[BoxData[
  RowBox[{
   StyleBox[
    OverscriptBox[
     StyleBox["y", "TI"], "^"], "TI"], "=", 
   RowBox[{
    SuperscriptBox[
     StyleBox["g", "TI"], 
     RowBox[{"-", 
      StyleBox["1", "TR"]}]], 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox[
       StyleBox["\[Beta]", "TR"], 
       StyleBox["0", "TR"]], "+", 
      RowBox[{
       SubscriptBox[
        StyleBox["\[Beta]", "TR"], 
        StyleBox["1", "TR"]], " ", 
       SubscriptBox[
        StyleBox["f", "TI"], 
        StyleBox["1", "TR"]]}], "+", 
      RowBox[{
       SubscriptBox[
        StyleBox["\[Beta]", "TR"], 
        StyleBox["2", "TR"]], " ", 
       SubscriptBox[
        StyleBox["f", "TI"], 
        StyleBox["2", "TR"]]}], "+", 
      StyleBox["\[Ellipsis]", "TR"]}], ")"}]}]}]], "InlineFormula",
  ExpressionUUID->"631bfe2b-76b4-4c70-898a-fb81fa0c2e4a"]
}], "Text",
 CellChangeTimes->{{3.434112612965945*^9, 3.4341126385971403`*^9}, {
   3.434992072481764*^9, 3.434992075638519*^9}, {3.435510526398472*^9, 
   3.4355105812969728`*^9}, 3.435510859957779*^9},
 TextAlignment->-0.5,ExpressionUUID->"cf602463-7d64-4d82-8b49-5a1f885cd7a2"],

Cell[TextData[{
 "where ",
 StyleBox["g", "TI"],
 " is an invertible function called the ",
 StyleBox["link",
  FontSlant->"Italic"],
 " function, and each observed ",
 Cell[BoxData[
  SubscriptBox[
   StyleBox["y", "TI"], 
   StyleBox["i", "TI"]]], "InlineFormula",ExpressionUUID->
  "3e938679-b78a-4b23-b4bb-fbef7f7611aa"],
 " is assumed to be from an exponential family distribution with mean ",
 Cell[BoxData[
  StyleBox[
   OverscriptBox[
    StyleBox[
     SubscriptBox[
      StyleBox["y", "TI"], 
      StyleBox["i", "TI"]], "TI"], "^"], "TI"]],ExpressionUUID->
  "03d63781-f6ca-4e26-92e0-0e17159f02c4"],
 ". Common special cases include linear, logistic, and probit regression, \
log-linear models for count data, and gamma and inverse Gaussian models. \
These and quasi\[Hyphen]likelihood models are all built\[Hyphen]in. Note that \
the errors are not independent of the ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]],ExpressionUUID->
  "a3b1b305-5001-4b3c-9238-95e027fa1a3a"],
 " values."
}], "Text",
 CellChangeTimes->{{3.4976266950134716`*^9, 3.4976267257357607`*^9}, {
   3.537697814733362*^9, 3.537697929846622*^9}, 
   3.537791918302227*^9},ExpressionUUID->"30c69640-5ae6-414a-a126-\
6a82c041ec90"],

Cell["Built\[Hyphen]in functions for generalized linear models include:", \
"Text",ExpressionUUID->"467b4121-d6d3-49d4-98b6-414ff8de0bf8"],

Cell[BoxData[
 PaneSelectorBox[{False->
  FrameBox[
   StyleBox["\<\"LinearModelFit\"\>", "OverviewSection",
    StripOnInput->False],
   BoxFrame->2,
   FrameMargins->{{15, 15}, {5, 5}},
   FrameStyle->None,
   RoundingRadius->5,
   StripOnInput->False], True->
  TemplateBox[{FrameBox[
     StyleBox[
     "\"LinearModelFit\"", "OverviewSection", StripOnInput -> False, 
      LineColor -> GrayLevel[1], FrontFaceColor -> GrayLevel[1], 
      BackFaceColor -> GrayLevel[1], GraphicsColor -> GrayLevel[1], FontColor -> 
      GrayLevel[1]], Background -> RGBColor[0.811765, 0.117647, 0.145098, 1], 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> None, RoundingRadius -> 
     5, StripOnInput -> False],"\" \[RightGuillemet] \"",FrameBox[
     StyleBox[
     "\"linear regression\"", "OverviewSection", StripOnInput -> False], 
     Background -> GrayLevel[1], BoxFrame -> 2, 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> 
     RGBColor[0.811765, 0.117647, 0.145098, 1], RoundingRadius -> 5, 
     StripOnInput -> False]},
   "Row",
   DisplayFunction->(
    RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ),
   InterpretationFunction->(RowBox[{"Row", "[", 
      RowBox[{"{", 
        RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )]}, Dynamic[
   CurrentValue["MouseOver"]],
  FrameMargins->0,
  ImageSize->Automatic]], "OverviewSection",
 GeneratedCell->True,
 CellAutoOverwrite->
  True,ExpressionUUID->"19910cf3-a36c-4726-ae5e-305ef872dbdd"],

Cell[BoxData[
 PaneSelectorBox[{False->
  FrameBox[
   StyleBox["\<\"LogitModelFit\"\>", "OverviewSection",
    StripOnInput->False],
   BoxFrame->2,
   FrameMargins->{{15, 15}, {5, 5}},
   FrameStyle->None,
   RoundingRadius->5,
   StripOnInput->False], True->
  TemplateBox[{FrameBox[
     StyleBox["\"LogitModelFit\"", "OverviewSection", 
      GrayLevel[1], StripOnInput -> False], 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> None, RoundingRadius -> 
     5, Background -> RGBColor[0.811765, 0.117647, 0.145098, 1], StripOnInput -> 
     False],"\" \[RightGuillemet] \"",FrameBox[
     StyleBox[
     "\"logistic regression\"", "OverviewSection", StripOnInput -> False], 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> 
     RGBColor[0.811765, 0.117647, 0.145098, 1], BoxFrame -> 2, RoundingRadius -> 
     5, Background -> GrayLevel[1], StripOnInput -> False]},
   "Row",
   DisplayFunction->(
    RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ),
   InterpretationFunction->(RowBox[{"Row", "[", 
      RowBox[{"{", 
        RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )]}, Dynamic[
   CurrentValue["MouseOver"]],
  FrameMargins->0,
  ImageSize->Automatic]], "OverviewSection",
 GeneratedCell->True,
 CellAutoOverwrite->
  True,ExpressionUUID->"32bfd67d-9240-439f-9b18-f94212d35e5f"],

Cell[BoxData[
 PaneSelectorBox[{False->
  FrameBox[
   StyleBox["\<\"ProbitModelFit\"\>", "OverviewSection",
    StripOnInput->False],
   BoxFrame->2,
   FrameMargins->{{15, 15}, {5, 5}},
   FrameStyle->None,
   RoundingRadius->5,
   StripOnInput->False], True->
  TemplateBox[{FrameBox[
     StyleBox["\"ProbitModelFit\"", "OverviewSection", 
      GrayLevel[1], StripOnInput -> False], 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> None, RoundingRadius -> 
     5, Background -> RGBColor[0.811765, 0.117647, 0.145098, 1], StripOnInput -> 
     False],"\" \[RightGuillemet] \"",FrameBox[
     StyleBox[
     "\"probit regression\"", "OverviewSection", StripOnInput -> False], 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> 
     RGBColor[0.811765, 0.117647, 0.145098, 1], BoxFrame -> 2, RoundingRadius -> 
     5, Background -> GrayLevel[1], StripOnInput -> False]},
   "Row",
   DisplayFunction->(
    RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ),
   InterpretationFunction->(RowBox[{"Row", "[", 
      RowBox[{"{", 
        RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )]}, Dynamic[
   CurrentValue["MouseOver"]],
  FrameMargins->0,
  ImageSize->Automatic]], "OverviewSection",
 GeneratedCell->True,
 CellAutoOverwrite->
  True,ExpressionUUID->"e87215e2-ad78-4097-a889-906e7aa31e7d"],

Cell[BoxData[
 PaneSelectorBox[{False->
  FrameBox[
   StyleBox["\<\"GeneralizedLinearModelFit\"\>", "OverviewSection",
    StripOnInput->False],
   BoxFrame->2,
   FrameMargins->{{15, 15}, {5, 5}},
   FrameStyle->None,
   RoundingRadius->5,
   StripOnInput->False], True->
  TemplateBox[{FrameBox[
     StyleBox["\"GeneralizedLinearModelFit\"", "OverviewSection", 
      GrayLevel[1], StripOnInput -> False], 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> None, RoundingRadius -> 
     5, Background -> RGBColor[0.811765, 0.117647, 0.145098, 1], StripOnInput -> 
     False],"\" \[RightGuillemet] \"",FrameBox[
     StyleBox[
     "\"generalized linear models with specified distributional structures \
and links\"", "OverviewSection", StripOnInput -> False], 
     FrameMargins -> {{15, 15}, {5, 5}}, FrameStyle -> 
     RGBColor[0.811765, 0.117647, 0.145098, 1], BoxFrame -> 2, RoundingRadius -> 
     5, Background -> GrayLevel[1], StripOnInput -> False]},
   "Row",
   DisplayFunction->(
    RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3}]& ),
   InterpretationFunction->(RowBox[{"Row", "[", 
      RowBox[{"{", 
        RowBox[{#, ",", #2, ",", #3}], "}"}], "]"}]& )]}, Dynamic[
   CurrentValue["MouseOver"]],
  FrameMargins->0,
  ImageSize->Automatic]], "OverviewSection",
 GeneratedCell->True,
 CellAutoOverwrite->
  True,ExpressionUUID->"006d5140-7b39-4ef6-bd06-40b65ff27909"],

Cell["\<\
Each of these functions support continuous and nominal predictor variables.\
\>", "Text",ExpressionUUID->"ff92bddf-04e1-467b-bb17-2e2d7adec4ed"],

Cell["", "Spacer",ExpressionUUID->"b6fe9a62-00a8-4e98-b1ea-829199fb0518"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->
  "SlideShowHeader",ExpressionUUID->"694740b3-3650-4a98-8883-f98ba0660e36"],

Cell[CellGroupData[{

Cell["Model Fitting and Analysis: GLM\[LongDash]Logit and Probit Models", \
"Section",
 CellChangeTimes->{{3.5376979476944723`*^9, 
  3.537697953724102*^9}},ExpressionUUID->"908ac7a9-d82f-4aac-8446-\
e7ff27a64fd3"],

Cell[TextData[{
 "Logit and probit models are commonly used to model probabilities. The \
observed probabilities are assumed to be success probabilities realized from \
binomial distributions. Logit and probit models can be fitted via the ",
 Cell[BoxData[
  ButtonBox["LogitModelFit",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/LogitModelFit"]], "InlineFormula",ExpressionUUID->
  "485ca748-7651-466f-8695-3dff31255249"],
 " and ",
 Cell[BoxData[
  ButtonBox["ProbitModelFit",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/ProbitModelFit"]], "InlineFormula",ExpressionUUID->
  "66c39b50-567a-4555-a840-8b9663402945"],
 " functions."
}], "Text",
 CellChangeTimes->{{3.436118003505559*^9, 3.436118005068839*^9}, {
  3.4378469431856613`*^9, 3.437846998661125*^9}, {3.4378491428924274`*^9, 
  3.437849160607336*^9}, {3.437929893859988*^9, 
  3.4379299332004642`*^9}},ExpressionUUID->"fe7ae131-68a2-4d24-9c39-\
c65342ea5ce6"],

Cell["\<\
Here is some data with responses written as number of successes over number \
of trials.\
\>", "MathCaption",
 CellChangeTimes->{{3.4378510742083063`*^9, 
  3.437851131699672*^9}},ExpressionUUID->"8b48fc1d-d959-499f-839f-\
a444fab02119"],

Cell[BoxData[
 RowBox[{"binomdata", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", 
      FractionBox["3", "8"]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"1.5", ",", 
      FractionBox["2", "10"]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"2.1", ",", 
      FractionBox["4", "6"]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"2.5", ",", 
      FractionBox["3", "7"]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"3.4", ",", 
      FractionBox["8", "11"]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"4", ",", 
      FractionBox["12", "14"]}], "}"}]}], "}"}]}]], "Input",ExpressionUUID->\
"e5476af2-0b82-4826-a213-a46eecb0ace4"],

Cell["The fractions are treated as probabilities.", "MathCaption",
 CellChangeTimes->{{3.4341126639277687`*^9, 3.4341127119416065`*^9}, {
  3.4349920829834433`*^9, 3.4349920843742914`*^9}, {3.437851138157092*^9, 
  3.437851167098218*^9}, {3.437929222040888*^9, 
  3.4379292221815014`*^9}},ExpressionUUID->"7b929f0e-1204-44bd-a668-\
72ef39f11579"],

Cell[BoxData[
 RowBox[{"logit1", "=", 
  RowBox[{"LogitModelFit", "[", 
   RowBox[{"binomdata", ",", "x", ",", "x"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.434112700709658*^9, 3.4341127077746634`*^9}, 
   3.434992087406026*^9, {3.4378470667545986`*^9, 
   3.437847080076215*^9}},ExpressionUUID->"f025e13f-e18a-4536-b0de-\
65d988580287"],

Cell["\<\
Weights can be used to incorporate the number of trials, in this case the \
denominators of the probabilities.\
\>", "MathCaption",
 CellChangeTimes->{{3.4378511700845795`*^9, 3.4378512131132*^9}, {
  3.437929233024349*^9, 
  3.4379292608657827`*^9}},ExpressionUUID->"d4f1b107-b758-4649-ae10-\
05c2c68398b6"],

Cell[BoxData[
 RowBox[{"logit2", "=", 
  RowBox[{"LogitModelFit", "[", 
   RowBox[{"binomdata", ",", "x", ",", "x", ",", 
    RowBox[{"Weights", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"8", ",", "10", ",", "6", ",", "7", ",", "11", ",", "14"}], 
      "}"}]}]}], "]"}]}]], "Input",ExpressionUUID->"e068b251-4d0e-4951-b53b-\
cf6fce662497"],

Cell["", "Spacer",ExpressionUUID->"46415ef7-f7fd-4257-ae6a-8742b82ecb76"],

Cell[TextData[{
 Cell[BoxData[
  ButtonBox["ProbitModelFit",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/ProbitModelFit"]], "InlineFormula",ExpressionUUID->
  "fcfe4d93-ba5a-4c87-9a83-e1cae01518fb"],
 " is the analogous function for probit models. The general features and \
available results are the same as those for ",
 Cell[BoxData[
  ButtonBox["LogitModelFit",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/LogitModelFit"]], "InlineFormula",ExpressionUUID->
  "1d5f0166-499c-4dc7-a071-79968a5b5ddf"],
 "."
}], "Text",ExpressionUUID->"fe213759-d776-4607-89b8-e3bf3a8fe526"],

Cell["This is a probit model for the same data.", "MathCaption",
 CellChangeTimes->{{3.437929580026726*^9, 
  3.437929593963066*^9}},ExpressionUUID->"d3f793c9-9758-4b90-9e5b-\
5f7ad8a5659f"],

Cell[BoxData[
 RowBox[{"probit", "=", 
  RowBox[{"ProbitModelFit", "[", 
   RowBox[{"binomdata", ",", "x", ",", "x"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.437929489362395*^9, 
  3.4379295999625673`*^9}},ExpressionUUID->"7c67a60a-d944-4527-abd0-\
d0919c102dfc"],

Cell["", "Spacer",ExpressionUUID->"da22daa6-f0ec-4e41-a864-4e22b69b7cd5"],

Cell[TextData[{
 "The functional form as well as numerous results for a fitted function can \
be obtained from the ",
 Cell[BoxData[
  ButtonBox["FittedModel",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/FittedModel"]], "InlineFormula",ExpressionUUID->
  "57fbdda0-1508-490b-995b-a7f03c150c18"],
 " as was the case for linear models."
}], "Text",
 CellChangeTimes->{{3.437929296815916*^9, 
  3.437929340406039*^9}},ExpressionUUID->"da5cb22a-26ca-462d-8783-\
156a25c1dae0"],

Cell["The fitted models with and without weights differ somewhat.", \
"MathCaption",
 CellChangeTimes->{{3.437929279426738*^9, 3.437929293691176*^9}, {
  3.437929384402378*^9, 
  3.4379294200869093`*^9}},ExpressionUUID->"d38f4267-d186-4135-bfeb-\
633c5efee5be"],

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Normal", "[", "logit1", "]"}], ",", "\"\<   \>\"", ",", 
    RowBox[{"Normal", "[", "logit2", "]"}], ",", "\"\<   \>\"", ",", 
    RowBox[{"Normal", "[", "probit", "]"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.4421383446848497`*^9, 3.442138427657987*^9}, {
  3.4976266186453*^9, 
  3.497626623036431*^9}},ExpressionUUID->"f1d3c3e0-4853-44a0-a2ba-\
2ff95ea75d55"],

Cell["", "Spacer",ExpressionUUID->"86ffebc5-56f6-4171-946f-c1b76270bbc6"],

Cell[TextData[{
 "The available properties differ somewhat from those for linear models. As \
with linear models, a list of available properties can be obtained by \
evaluating the ",
 Cell[BoxData[
  ButtonBox["FittedModel",
   BaseStyle->"Link"]], "InlineFormula",ExpressionUUID->
  "191b8231-bbfa-49f7-b708-e6478c547f4d"],
 " object with argument ",
 Cell[BoxData[
 "\"\<Properties\>\""], "InlineFormula",ExpressionUUID->
  "aeaca802-ba1e-44b1-94a0-104493d5a81e"],
 "."
}], "Text",ExpressionUUID->"d88e78f2-2809-4f3c-86af-98b96b856c8a"],

Cell["Here are the parameter tables for the three models.", "MathCaption",
 CellChangeTimes->{{3.4379294223679695`*^9, 3.437929444584871*^9}, {
  3.437930280343455*^9, 3.437930281468361*^9}, {3.497626889077409*^9, 
  3.4976268899055815`*^9}},ExpressionUUID->"1cbdec7d-2b00-4b1f-8db8-\
d0440659de23"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"logit1", "[", "\"\<ParameterTable\>\"", "]"}], ",", 
   RowBox[{"logit2", "[", "\"\<ParameterTable\>\"", "]"}], ",", 
   RowBox[{"probit", "[", "\"\<ParameterTable\>\"", "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.4378492794989176`*^9, 3.4378493012321234`*^9}, {
  3.497626631318635*^9, 
  3.4976266387413645`*^9}},ExpressionUUID->"dc2e6ce1-228b-4d93-ac1d-\
b93b0150b6c3"],

Cell["", "Spacer",ExpressionUUID->"58cb542a-4997-4b0d-86d7-97cdd8a8c7a6"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->
  "SlideShowHeader",ExpressionUUID->"9042abc9-59f3-47fb-a4f1-69481e50350d"],

Cell[CellGroupData[{

Cell["Model Fitting and Analysis: GLM\[LongDash]Poisson Count Models", \
"Section",
 CellChangeTimes->{{3.537697986015873*^9, 
  3.537697990885166*^9}},ExpressionUUID->"99c5626b-9a7e-494c-bc95-\
30016cfcb1e0"],

Cell[TextData[{
 "Logit and probit models are generalized linear models for probability \
responses. These models could equivalently be fit via ",
 Cell[BoxData[
  ButtonBox["GeneralizedLinearModelFit",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/GeneralizedLinearModelFit"]], "InlineFormula",
  ExpressionUUID->"0b5c6eda-2c07-4042-8cf9-f3c316cdcd7e"],
 " using the option ",
 Cell[BoxData[
  RowBox[{
   ButtonBox["ExponentialFamily",
    BaseStyle->"Link"], "\[Rule]", "\"\<Binomial\>\""}]], "InlineFormula",
  ExpressionUUID->"1889a598-3e3b-476a-89d0-af68f73fa7b4"],
 " and an appropriate choice of ",
 Cell[BoxData[
  ButtonBox["LinkFunction",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/LinkFunction"]], "InlineFormula",ExpressionUUID->
  "d43667cf-1ee2-4e1f-9c26-3a8a6db42db5"],
 ". "
}], "Text",ExpressionUUID->"3576af3e-5881-4c02-b8ac-ac6fe11830ec"],

Cell["\<\
Models of count data commonly assume Poisson-distributed responses. Predictor \
variables can be continuous (real\[Hyphen]valued) or nominal (taking on one \
of a finite number of distinct names or categories).\
\>", "Text",
 CellChangeTimes->{{3.437934672273569*^9, 3.4379348243465724`*^9}, 
   3.537698015493516*^9},ExpressionUUID->"768a7299-df79-4080-ba07-\
7751dd7137bc"],

Cell["Here is some count data for two categorical variables.", "MathCaption",
 CellChangeTimes->{{3.436118003505559*^9, 3.436118005068839*^9}, {
  3.4378478174013414`*^9, 3.4378478299878893`*^9}, {3.437934839475638*^9, 
  3.437934892442997*^9}},ExpressionUUID->"af08bea6-45c9-43eb-9666-\
2e0eff63cff1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"countdata", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", "agree", ",", "53"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"a", ",", "disagree", ",", "24"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"a", ",", "undecided", ",", "13"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"b", ",", "agree", ",", "78"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"b", ",", "disagree", ",", "48"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"b", ",", "undecided", ",", "110"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"c", ",", "agree", ",", "20"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"c", ",", "disagree", ",", "58"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"c", ",", "undecided", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"d", ",", "agree", ",", "42"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"d", ",", "disagree", ",", "38"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"d", ",", "undecided", ",", "4"}], "}"}]}], "}"}]}], 
  ";"}]], "Input",ExpressionUUID->"c63de1d6-b0ae-4f8c-b092-66093fb96f0a"],

Cell["", "Spacer",ExpressionUUID->"99964fc3-18be-42a6-856b-3cb61a9345bc"],

Cell[TextData[{
 "The ",
 Cell[BoxData[
  ButtonBox["NominalVariables",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/NominalVariables"]], "InlineFormula",
  ExpressionUUID->"51d62fda-a44e-4c95-86b8-9826fb9ed380"],
 " option can be used to specify which variables are to be treated as nominal."
}], "Text",
 CellChangeTimes->{{3.437935169329904*^9, 3.4379351957901397`*^9}, 
   3.4379352299555707`*^9, 
   3.437935270200761*^9},ExpressionUUID->"3ccdacc2-c212-47df-88e2-\
89a0efb68b66"],

Cell["The default Poisson model is a log-linear model.", "MathCaption",
 CellChangeTimes->{{3.4341126639277687`*^9, 3.4341127119416065`*^9}, {
   3.4349920829834433`*^9, 3.4349920843742914`*^9}, {3.4379352742174654`*^9, 
   3.437935286580162*^9}, 
   3.437936828994652*^9},ExpressionUUID->"e4065297-2792-4fcb-9162-\
72d7b7cad0ae"],

Cell[BoxData[
 RowBox[{"loglinmodel", "=", 
  RowBox[{"GeneralizedLinearModelFit", "[", 
   RowBox[{"countdata", ",", 
    RowBox[{"{", 
     RowBox[{"group", ",", "opinion"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"group", ",", "opinion"}], "}"}], ",", 
    RowBox[{"ExponentialFamily", "\[Rule]", "\"\<Poisson\>\""}], ",", 
    RowBox[{"NominalVariables", "\[Rule]", "All"}]}], "]"}]}]], "Input",Expres\
sionUUID->"e2639372-e5a1-4a94-b5a4-9aebab8eb5d2"],

Cell["", "Spacer",ExpressionUUID->"c15bf097-8067-42c0-a9fb-d732edfcc02f"],

Cell[TextData[{
 "As with continuous predictors, the ",
 Cell[BoxData[
  ButtonBox["FittedModel",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/FittedModel"]], "InlineFormula",ExpressionUUID->
  "3420ad27-c5cb-4548-aaac-4450faca5da0"],
 " can be evaluated at a particular point. Terms arising from nominal \
variables are represented as ",
 Cell[BoxData[
  ButtonBox["DiscreteIndicator",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/DiscreteIndicator"]], "InlineFormula",
  ExpressionUUID->"116407b7-1232-4365-83e5-129c147919b0"],
 " functions."
}], "Text",
 CellChangeTimes->{{3.43793548100741*^9, 3.437935517329671*^9}, {
   3.4379355534643817`*^9, 3.4379355918340673`*^9}, 
   3.4379368311358523`*^9},ExpressionUUID->"cab80976-3fee-4d24-b58e-\
c0763e829b7c"],

Cell[TextData[{
 "These are the predicted count for group ",
 StyleBox["a", "MR"],
 " and ",
 StyleBox["agree", "MR"],
 ", and the predicted function for group ",
 StyleBox["a", "MR"],
 "."
}], "MathCaption",
 CellChangeTimes->{{3.4379355952881207`*^9, 3.437935645082752*^9}, {
  3.437935715476669*^9, 
  3.4379357289802976`*^9}},ExpressionUUID->"c1de55b8-8b0e-4b2f-a3a0-\
ace378d90b09"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"loglinmodel", "[", 
    RowBox[{"a", ",", "agree"}], "]"}], ",", 
   RowBox[{"loglinmodel", "[", 
    RowBox[{"a", ",", "opinion"}], "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.437935406690564*^9, 
  3.437935440730962*^9}},ExpressionUUID->"cc90ea2b-9dc5-4c5f-96e6-\
61436ced720b"],

Cell["", "Spacer",ExpressionUUID->"37f931e8-580f-492f-ba82-ff88025ade51"],

Cell["\<\
Other forms of the Poisson model can be fitted by specifying a different \
invertible link function.\
\>", "Text",
 CellChangeTimes->{{3.437935737482582*^9, 3.437935782400903*^9}, {
  3.537698055399872*^9, 
  3.537698056036963*^9}},ExpressionUUID->"d818fe19-323b-4188-88b0-\
b43f2971b4b4"],

Cell["This gives a linear Poisson count model.", "MathCaption",
 CellChangeTimes->{{3.4379357869646297`*^9, 
  3.4379358132842026`*^9}},ExpressionUUID->"a052de68-cdcf-433e-a383-\
b6191a0b1f87"],

Cell[BoxData[
 RowBox[{"linmodel", "=", 
  RowBox[{"GeneralizedLinearModelFit", "[", 
   RowBox[{"countdata", ",", 
    RowBox[{"{", 
     RowBox[{"group", ",", "opinion"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"group", ",", "opinion"}], "}"}], ",", 
    RowBox[{"ExponentialFamily", "\[Rule]", "\"\<Poisson\>\""}], ",", 
    RowBox[{"NominalVariables", "\[Rule]", "All"}], ",", 
    RowBox[{"LinkFunction", "\[Rule]", "\"\<IdentityLink\>\""}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4379352963953*^9, 
  3.4379353179948545`*^9}},ExpressionUUID->"70c48c33-b48d-443e-b4bd-\
92850bc00c39"],

Cell["\<\
This model is easily visualized using the charting functions.\
\>", "MathCaption",
 CellChangeTimes->{{3.443780505377714*^9, 3.443780534303816*^9}, 
   3.443780639162862*^9},ExpressionUUID->"f2af22ce-c16d-4b8f-8205-\
e9933dba8d6b"],

Cell[BoxData[
 RowBox[{"BarChart", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"linmodel", "[", 
        RowBox[{"a", ",", "#"}], "]"}], ",", 
       RowBox[{"linmodel", "[", 
        RowBox[{"b", ",", "#"}], "]"}], ",", 
       RowBox[{"linmodel", "[", 
        RowBox[{"c", ",", "#"}], "]"}]}], "}"}], "&"}], "/@", 
    RowBox[{"{", 
     RowBox[{"agree", ",", "disagree", ",", "undecided"}], "}"}]}], ",", 
   RowBox[{"ChartElementFunction", "\[Rule]", "\"\<GlassRectangle\>\""}], ",", 
   RowBox[{"ChartLabels", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "\"\<agree\>\"", ",", "\"\<disagree\>\"", ",", "\"\<undecided\>\""}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<a\>\"", ",", "\"\<b\>\"", ",", "\"\<c\>\""}], "}"}]}], 
     "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4437799596346483`*^9, 3.4437800101139317`*^9}, {
  3.44378007558885*^9, 3.443780094926303*^9}, {3.443780340549735*^9, 
  3.4437803860999403`*^9}},ExpressionUUID->"1edc50d6-d3fa-407a-9850-\
c010b623d639"],

Cell["", "Spacer",ExpressionUUID->"35db6bbc-2104-435e-983e-e455008c9eb8"],

Cell[TextData[{
 Cell[BoxData[
  ButtonBox["GeneralizedLinearModelFit",
   BaseStyle->"Link"]], "InlineFormula",ExpressionUUID->
  "0c09880e-bff0-407f-9170-4ff34780499b"],
 "\[CloseCurlyQuote]s ",
 Cell[BoxData[
  ButtonBox["ExponentialFamily",
   BaseStyle->"Link"]], "InlineFormula",ExpressionUUID->
  "ea09d590-e5be-4c6d-bf9f-784d78b1a46f"],
 " option also includes special cases for gamma and inverse Gaussian models \
as well as a general quasi\[Hyphen]likelihood framework for defining \
additional model structures."
}], "Text",
 CellChangeTimes->{{3.4977167692543116`*^9, 3.497716878431077*^9}, {
  3.497716926948876*^9, 
  3.497716964997455*^9}},ExpressionUUID->"3d396798-fce9-4add-93c5-\
55ec833b9ee1"],

Cell["", "Spacer",ExpressionUUID->"76cc7ce4-9631-430a-b8dc-0e3c33a62b88"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->
  "SlideShowHeader",ExpressionUUID->"3dc8af74-6103-4cf4-a428-829d7fe3929d"],

Cell[CellGroupData[{

Cell["Model Fitting and Analysis: Nonlinear Regression", "Section",
 CellChangeTimes->{
  3.5376980715882874`*^9},ExpressionUUID->"d660501a-fd8a-4ce2-854e-\
6fcbd443b279"],

Cell[TextData[{
 "The ",
 Cell[BoxData[
  ButtonBox["NonlinearModelFit",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/NonlinearModelFit"]], "InlineFormula",
  ExpressionUUID->"e94436c2-2ae0-44c8-aef4-bba7f9e19f8d"],
 " function works for nonlinear least squares models in much the same way the \
other model fit functions we have just seen work with linear and generalized \
linear models."
}], "Text",
 CellChangeTimes->{{3.434112612965945*^9, 3.4341126385971403`*^9}, {
  3.437937105459571*^9, 
  3.437937154260797*^9}},ExpressionUUID->"200069e8-5608-4534-8105-\
e11b512c80ad"],

Cell["\<\
This fits the previously used linear dataset to a nonlinear model.\
\>", "MathCaption",
 CellChangeTimes->{{3.4380898385465317`*^9, 3.438089858468534*^9}, {
   3.537698083525755*^9, 3.537698086837751*^9}, 
   3.5377916781728077`*^9},ExpressionUUID->"612fbb8e-a4a0-4a29-8937-\
0192cac0b501"],

Cell[BoxData[
 RowBox[{"nlm", "=", 
  RowBox[{"NonlinearModelFit", "[", 
   RowBox[{"lineardata", ",", 
    RowBox[{"Sqrt", "[", 
     RowBox[{
      RowBox[{"a", "*", "x"}], "+", 
      RowBox[{"b", "*", "y", "*", "z"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4341126420591497`*^9, 3.4341126450042067`*^9}, {
   3.4341126979682484`*^9, 3.434112698532195*^9}, 3.4341127487704916`*^9, 
   3.434113863963032*^9, 3.438088492499484*^9, {3.4383659982328215`*^9, 
   3.438366010482587*^9}, {3.438366183416766*^9, 3.438366187432314*^9}, {
   3.438366359882128*^9, 3.438366458848978*^9}, {3.4383664994419484`*^9, 
   3.43836650300438*^9}, {3.4383665347068963`*^9, 
   3.438366534831894*^9}},ExpressionUUID->"f6a29985-d2bf-46b9-99fe-\
69fd3f1784c5"],

Cell["", "Spacer",ExpressionUUID->"880546ac-3d0a-4bc0-a092-872500ffd762"],

Cell[TextData[{
 "Nonlinear model properties differ somewhat from linear and generalized \
linear properties, and a list can be obtained by evaluating ",
 StyleBox["nlm[\[OpenCurlyDoubleQuote]Properties\[CloseCurlyDoubleQuote]]", 
  "MR"],
 "."
}], "Text",ExpressionUUID->"19477078-8fa4-4b80-8ef6-e04ef69d8591"],

Cell["Here we obtain the functional form of the fitted model.", "MathCaption",ExpressionUUID->"0dde4428-a9d1-4052-8466-6229774566f6"],

Cell[BoxData[
 RowBox[{"Normal", "[", "nlm", "]"}]], "Input",
 CellChangeTimes->{{3.4341127209334316`*^9, 3.434112727575476*^9}, {
   3.442051958332156*^9, 3.44205198972167*^9}, 3.442054069820277*^9, {
   3.442059663835105*^9, 
   3.4420596835662527`*^9}},ExpressionUUID->"be46d472-7e6d-42c3-9844-\
4d4df68f85b5"],

Cell["", "Spacer",ExpressionUUID->"01e351e2-b27e-4036-bbc2-e01a97dcaf4d"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->
  "SlideShowHeader",ExpressionUUID->"328e184d-66bb-41fa-842b-2820f6414c3e"],

Cell[CellGroupData[{

Cell["\<\
Model Fitting and Analysis: Nonlinear Regression\[LongDash]Starting Values \
and Constraints\
\>", "Section",
 CellChangeTimes->{{3.5376980998321*^9, 
  3.537698113663459*^9}},ExpressionUUID->"4b494513-2c38-4079-8a8a-\
dd7d71191be5"],

Cell["\<\
Fitting nonlinear models requires an iterative process. Choosing good \
starting values for parameters can be important to get good results. By \
default, all parameters have starting value 1.\
\>", "Text",ExpressionUUID->"cac9f346-6b2c-4a4e-b178-61dcf63caa24"],

Cell[TextData[{
 "Here the model is changed to have a negative sign in front of the \
coefficient ",
 Cell[BoxData[
  StyleBox["a", "MR"]], "InlineFormula",ExpressionUUID->
  "6ec2c63b-4f2f-4d04-8631-63168db55ca6"],
 "."
}], "MathCaption",
 CellChangeTimes->{{3.4383674150024943`*^9, 
  3.438367445892526*^9}},ExpressionUUID->"338420dc-bfca-44be-9a7e-\
984c34fd24b3"],

Cell[BoxData[
 RowBox[{"NonlinearModelFit", "[", 
  RowBox[{"lineardata", ",", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "a"}], "*", "x"}], "+", 
     RowBox[{"b", "*", "y", "*", "z"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4383665921901674`*^9, 
  3.438366592705783*^9}},ExpressionUUID->"f62d3c74-b95b-48dd-92b2-\
11d54f47d535"],

Cell["", "MR",ExpressionUUID->"427f3635-cc2b-4e6e-8e26-15ea1aea71b8"],

Cell[TextData[{
 "This is really the same model as before except that the sign for the \
coefficient ",
 StyleBox["a", "MR"],
 " is different. In this case the fitting fails because the starting values \
result in complex numbers. The iterative method would need to pass from \
positive values of ",
 StyleBox["a", "MR"],
 " to negative values with this starting value."
}], "Text",ExpressionUUID->"0b010929-ddc9-46ec-aa9f-a0ba06adb30e"],

Cell[TextData[{
 "Giving a negative starting value for ",
 StyleBox["a", "MR"],
 " gets a good result in this case."
}], "MathCaption",
 CellChangeTimes->{{3.4383675293127995`*^9, 3.4383675508280115`*^9}, {
  3.4383675894835196`*^9, 
  3.4383676246390944`*^9}},ExpressionUUID->"4a7bbe00-e2b6-47c9-89d3-\
d19b4633ef07"],

Cell[BoxData[
 RowBox[{"nlm2", "=", 
  RowBox[{"NonlinearModelFit", "[", 
   RowBox[{"lineardata", ",", 
    RowBox[{"Sqrt", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "a"}], "*", "x"}], "+", 
      RowBox[{"b", "*", "y", "*", "z"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"a", ",", 
        RowBox[{"-", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"b", ",", "5"}], "}"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.438366515847883*^9, 3.4383665377068386`*^9}, {
  3.438367699278286*^9, 
  3.438367700512637*^9}},ExpressionUUID->"c8cb522a-a2cb-4957-9dca-\
f8cb65095ddb"],

Cell["The estimates are equivalent up to a sign change.", "MathCaption",
 CellChangeTimes->{{3.43836773473073*^9, 
  3.438367758355277*^9}},ExpressionUUID->"3c923fd0-b010-4488-892d-\
6b98452dc696"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"nlm", "[", "\"\<ParameterTable\>\"", "]"}], ",", 
   RowBox[{"nlm2", "[", "\"\<ParameterTable\>\"", "]"}]}], "}"}]], "Input",Exp\
ressionUUID->"57f2d68d-5dbc-4773-9922-8d3cce3b48d8"],

Cell["", "Spacer",ExpressionUUID->"5337a8fb-6ef8-43d1-98a5-c881026c238d"],

Cell["\<\
Constraints can also be used. Some properties derived from unconstrained \
distributional assumptions, however, may not be valid.\
\>", "Text",ExpressionUUID->"8f16cd84-c848-4830-b444-610049fa9c71"],

Cell[TextData[{
 "Here ",
 StyleBox["b", "MR"],
 " is constrained to be greater than 15."
}], "MathCaption",ExpressionUUID->"671f28e6-e8a2-43a5-9f72-2a1575b2cd97"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"nlmc", "=", 
   RowBox[{"NonlinearModelFit", "[", 
    RowBox[{"lineardata", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{"a", "*", "x"}], "+", 
         RowBox[{"b", "*", "y", "*", "z"}]}], "]"}], ",", 
       RowBox[{"b", ">", "15"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"a", ",", "b"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Normal", "[", "nlmc", "]"}]}], "Input",
 CellChangeTimes->{{3.434112735627389*^9, 3.4341127926800475`*^9}, 
   3.434113866954856*^9, 3.4380884931244926`*^9, {3.438367792713992*^9, 
   3.438367793448353*^9}, {3.44213911641383*^9, 
   3.442139124539835*^9}},ExpressionUUID->"6b256822-f367-4f3f-bf2c-\
d00e4c91a5c9"],

Cell["", "MR",ExpressionUUID->"11f34f7d-c4bf-450f-865c-62e87587aaeb"],

Cell["\<\
A warning is generated if affected properties are requested. If the estimates \
are far from the constraint boundaries so that the constraint region covers \
nearly all of the probability for the parameter vector, results from the \
unconstrained distributional assumptions are likely fine.\
\>", "Text",
 CellChangeTimes->{{3.4383701987928834`*^9, 3.438370278516427*^9}, {
  3.438370399071311*^9, 3.438370470037462*^9}, {3.438370735605375*^9, 
  3.4383707736062007`*^9}},ExpressionUUID->"4ebbc8d9-3661-4c5a-9a1b-\
098355044f40"],

Cell["\<\
In this case the confidence intervals contain points outside the constraint \
region.\
\>", "MathCaption",
 CellChangeTimes->{{3.4383703041317987`*^9, 
  3.438370356832533*^9}},ExpressionUUID->"d3abc553-bf37-442c-9833-\
5140cd78dc5d"],

Cell[BoxData[
 RowBox[{"nlmc", "[", "\"\<ParameterConfidenceIntervals\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.4383683117866964`*^9, 
  3.4383683583858447`*^9}},ExpressionUUID->"0c9fa548-49eb-42e3-ac35-\
d052e85883fa"],

Cell["", "Spacer",ExpressionUUID->"f4d013fc-bb06-4a5b-9e17-121242739af6"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->
  "SlideShowHeader",ExpressionUUID->"5a3339e5-e2b5-4d72-819c-dcd9f8812df8"],

Cell[CellGroupData[{

Cell["Model Fitting and Analysis: ANOVA", "Section",ExpressionUUID->"d5c119f7-337f-4c23-895c-22c7219d768f"],

Cell[TextData[{
 "The analysis of variance (ANOVA) model is a categorical linear regression \
model. While such models can be fit and analyzed using ",
 Cell[BoxData[
  ButtonBox["LinearModelFit",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/LinearModelFit"]], "InlineFormula",ExpressionUUID->
  "f7fe5978-7d8e-4526-ac65-db99b416a687"],
 " with ",
 Cell[BoxData[
  ButtonBox["NominalVariables",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/NominalVariables"]], "InlineFormula",
  ExpressionUUID->"458ac0c9-dcb7-464b-be2c-2f9b54b9f9bc"],
 ", ",
 Cell[BoxData[
  ButtonBox["ANOVA",
   BaseStyle->"Link",
   ButtonData->"paclet:ANOVA/ref/ANOVA"]], "InlineFormula",ExpressionUUID->
  "2247dac7-847e-4f0e-9e4b-500731d48bbb"],
 " provides direct computation of cell means and tests of categorical \
differences."
}], "Text",
 CellChangeTimes->{{3.4361177128502846`*^9, 3.436117802201993*^9}, {
  3.4361178412996264`*^9, 3.4361178426596794`*^9}, {3.4361183347544837`*^9, 
  3.436118343958728*^9}},ExpressionUUID->"9a4ba124-a377-4664-bfd2-\
55657fbcf14c"],

Cell["Here we import some data from a text file.", "MathCaption",ExpressionUUID->"c914c148-fb91-4cc3-949f-2e58e132ff70"],

Cell[BoxData[
 RowBox[{"anovadata", "=", 
  RowBox[{"Import", "[", 
   RowBox[{"\"\<anovadata.txt\>\"", ",", "\"\<Table\>\""}], "]"}]}]], "Input",\
ExpressionUUID->"e6e54fbe-b3b5-4f32-9b71-dd4de441a79c"],

Cell[TextData[{
 "The ",
 Cell[BoxData[
  ButtonBox["ANOVA",
   BaseStyle->"Link",
   ButtonData->"paclet:ANOVA/ref/ANOVA"]], "InlineFormula",ExpressionUUID->
  "d3e5880a-8e9c-4e08-a4a4-3bb0fdb02517"],
 " function is defined in the ",
 ButtonBox["ANOVA",
  BaseStyle->"Link",
  ButtonData->"paclet:ANOVA/guide/AnalysisOfVariancePackage"],
 " package."
}], "MathCaption",ExpressionUUID->"6836e6d2-4cc9-4ad5-bee8-756c76aed3ea"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<ANOVA`\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.4355133050981565`*^9, 
  3.435513309939043*^9}},ExpressionUUID->"6eadb6e8-fcb3-4126-92c0-\
e0256bcc1b32"],

Cell["\<\
By default an ANOVA table and table of cell means are returned.\
\>", "MathCaption",ExpressionUUID->"39695bc0-631e-4fc0-a694-43730492a2a0"],

Cell[BoxData[
 RowBox[{"ANOVA", "[", 
  RowBox[{"anovadata", ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y"}], "}"}]}], "]"}]], "Input",ExpressionUUID->\
"9309984a-5268-4126-87c5-fefc5e736696"],

Cell["", "MR",ExpressionUUID->"d7fb671e-3aca-45a6-9121-ac0095ee92ee"],

Cell["\<\
The cell means can be omitted and significance tests performed if desired.\
\>", "Text",ExpressionUUID->"62563056-432b-4d8a-b40b-f84fe9677c94"],

Cell["\<\
This gives an analysis of variance performing Bonferroni and Tukey tests for \
significant differences between levels of categorical variables.\
\>", "MathCaption",ExpressionUUID->"67f2f6df-d92c-4eb8-a6fa-cbfbb3f0fe2c"],

Cell[BoxData[
 RowBox[{"ANOVA", "[", 
  RowBox[{"anovadata", ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y"}], "}"}], ",", 
   RowBox[{"CellMeans", "\[Rule]", "False"}], ",", 
   RowBox[{"PostTests", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Bonferroni", ",", "Tukey"}], "}"}]}]}], "]"}]], "Input",Expressi\
onUUID->"c5e3f497-a6fc-4f54-8a45-c0c83b110276"],

Cell[TextData[{
 "The same model could be fit using ",
 Cell[BoxData[
  ButtonBox["LinearModelFit",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/LinearModelFit"]], "InlineFormula",ExpressionUUID->
  "92e65484-ba20-40ba-b6a6-85106c60aa27"],
 " as follows."
}], "MathCaption",
 CellChangeTimes->{{3.4361182893864965`*^9, 
  3.4361183299101443`*^9}},ExpressionUUID->"5c9a0bab-aaee-4721-9a0c-\
e6631ea7b9f7"],

Cell[BoxData[
 RowBox[{"anovalm", "=", 
  RowBox[{"LinearModelFit", "[", 
   RowBox[{"anovadata", ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y"}], "}"}], ",", 
    RowBox[{"NominalVariables", "\[Rule]", "All"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4361180679462805`*^9, 
  3.4361180971715755`*^9}},ExpressionUUID->"f57b14cb-4306-4d4a-af40-\
5d22bd3622a8"],

Cell[BoxData[
 RowBox[{"anovalm", "[", "\"\<ANOVATable\>\"", "]"}]], "Input",ExpressionUUID->"33a22da7-da08-41d5-b1d7-388ff52d39dc"],

Cell["", "Spacer",ExpressionUUID->"12883c87-c7dc-48a0-a6d1-f34adac0b91c"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->
  "SlideShowHeader",ExpressionUUID->"592ec17c-dfd2-4405-b64d-f747750d2a30"],

Cell[CellGroupData[{

Cell["Initialization", "Section",
 InitializationGroup->
  True,ExpressionUUID->"d2f6bb35-6f9d-4644-92ba-108b5946139d"],

Cell[CellGroupData[{

Cell["StyleTable", "MoreExamplesSection",ExpressionUUID->"f9d8b752-280d-423d-9bb6-fa41eb1cb070"],

Cell[BoxData[
 RowBox[{
  RowBox[{"StyleTable", "[", 
   RowBox[{"tbl_Style", ",", 
    RowBox[{"rools_List", "?", "OptionQ"}]}], "]"}], ":=", 
  RowBox[{"tbl", "/.", 
   RowBox[{
    RowBox[{"Style", "[", 
     RowBox[{"x_", ",", "\"\<DialogStyle\>\""}], "]"}], "\[RuleDelayed]", 
    RowBox[{"Style", "[", 
     RowBox[{"x", ",", "\"\<DialogStyle\>\"", ",", 
      RowBox[{"Sequence", "@@", "rools"}]}], "]"}]}]}]}]], "Input",ExpressionU\
UID->"59377da9-a95a-41ae-9486-b8b81c94df75"]
}, Closed]],

Cell[CellGroupData[{

Cell["Overview Mouseover", "MoreExamplesSection",
 CellChangeTimes->{{3.49896919710295*^9, 
  3.498969204966164*^9}},ExpressionUUID->"d7153357-120d-4d53-b003-\
315473acd215"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"m8red", "[", "a_", "]"}], ":=", 
   RowBox[{"RGBColor", "[", 
    RowBox[{"0.811765", ",", "0.117647", ",", "0.145098", ",", "a"}], "]"}]}],
   ";"}]], "Input",ExpressionUUID->"09611e8d-9e7d-4597-96a5-bb272fc3d27c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"OverviewMouseover", "[", 
   RowBox[{"header_", ",", "subs_"}], "]"}], ":=", 
  RowBox[{"CellPrint", "@", 
   RowBox[{"Cell", "[", 
    RowBox[{
     RowBox[{"BoxData", "[", 
      RowBox[{"ToBoxes", "@", 
       RowBox[{"Mouseover", "[", 
        RowBox[{
         RowBox[{"Framed", "[", 
          RowBox[{
           RowBox[{"Style", "[", 
            RowBox[{"header", ",", "\"\<OverviewSection\>\""}], "]"}], ",", 
           RowBox[{"FrameMargins", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"15", ",", "15"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"5", ",", "5"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"BoxFrame", "\[Rule]", "2"}], ",", 
           RowBox[{"FrameStyle", "\[Rule]", "None"}], ",", 
           RowBox[{"RoundingRadius", "\[Rule]", "5"}]}], "]"}], ",", 
         "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{"Evaluate", "@", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"subs", "\[Equal]", "\"\<\>\""}], ",", 
            RowBox[{"Framed", "[", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{
               "header", ",", "\"\<OverviewSection\>\"", ",", "White"}], 
               "]"}], ",", 
              RowBox[{"FrameMargins", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"15", ",", "15"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"5", ",", "5"}], "}"}]}], "}"}]}], ",", 
              RowBox[{"BoxFrame", "\[Rule]", "2"}], ",", 
              RowBox[{"FrameStyle", "\[Rule]", "None"}], ",", 
              RowBox[{"RoundingRadius", "\[Rule]", "5"}], ",", 
              RowBox[{"Background", "\[Rule]", 
               RowBox[{"m8red", "[", "1", "]"}]}]}], "]"}], ",", 
            RowBox[{"Row", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Framed", "[", 
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{
                  "header", ",", "\"\<OverviewSection\>\"", ",", "White"}], 
                  "]"}], ",", 
                 RowBox[{"FrameMargins", "\[Rule]", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{"15", ",", "15"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"5", ",", "5"}], "}"}]}], "}"}]}], ",", 
                 RowBox[{"FrameStyle", "\[Rule]", "None"}], ",", 
                 RowBox[{"RoundingRadius", "\[Rule]", "5"}], ",", 
                 RowBox[{"Background", "\[Rule]", 
                  RowBox[{"m8red", "[", "1", "]"}]}]}], "]"}], ",", 
               "\"\< \[RightGuillemet] \>\"", ",", 
               RowBox[{"Framed", "[", 
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{"subs", ",", "\"\<OverviewSection\>\""}], "]"}], 
                 ",", 
                 RowBox[{"FrameMargins", "\[Rule]", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{"15", ",", "15"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"5", ",", "5"}], "}"}]}], "}"}]}], ",", 
                 RowBox[{"FrameStyle", "\[Rule]", 
                  RowBox[{"m8red", "[", "1", "]"}]}], ",", 
                 RowBox[{"BoxFrame", "\[Rule]", "2"}], ",", 
                 RowBox[{"RoundingRadius", "\[Rule]", "5"}], ",", 
                 RowBox[{"Background", "\[Rule]", "White"}]}], "]"}]}], "}"}],
              "]"}]}], "]"}]}]}], "]"}]}], "]"}], ",", 
     "\"\<OverviewSection\>\""}], "]"}]}]}]], "Input",ExpressionUUID->\
"8cd0a36f-40c4-4757-b872-08aac82be56a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MapThread", "[", 
     RowBox[{"OverviewMouseover", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
          "\"\<\!\(\*StyleBox[\"Descriptive\",FontWeight->\"Bold\"]\)\!\(\*\
StyleBox[\" \
\",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"and\",FontWeight->\"Bold\"]\)\!\(\*\
StyleBox[\" \
\",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Exploratory\",FontWeight->\"Bold\"]\
\)\!\(\*StyleBox[\" \
\",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"S\",FontWeight->\"Bold\"]\)\!\(\*\
StyleBox[\"tatistics\",FontWeight->\"Bold\"]\)\>\"", ",", 
           "\"\<descriptive measures and charts, smoothing, transformations, \
clustering, visualization\>\""}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
          "\"\<\!\(\*StyleBox[\"Statistical\",FontWeight->\"Bold\"]\)\!\(\*\
StyleBox[\" \",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"D\",FontWeight->\"Bold\
\"]\)\!\(\*StyleBox[\"istributions\",FontWeight->\"Bold\"]\)\>\"", ",", 
           "\"\<parametric and nonparametric distributions, properties of \
distributions, random numbers, parameter estimation, visualization\>\""}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
          "\"\<\!\(\*StyleBox[\"Hypothesis\",FontWeight->\"Bold\"]\)\!\(\*\
StyleBox[\" \",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"T\",FontWeight->\"Bold\
\"]\)\!\(\*StyleBox[\"esting\",FontWeight->\"Bold\"]\)\>\"", ",", 
           "\"\<tests of distributional goodness of fit, tests of location \
and scale\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
          "\"\<\!\(\*StyleBox[\"Model\",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\
\" \",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"F\",FontWeight->\"Bold\"]\)\!\(\
\*StyleBox[\"itting\",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"and\",FontWeight->\"Bold\"]\)\!\(\*\
StyleBox[\" \",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"A\",FontWeight->\"Bold\
\"]\)\!\(\*StyleBox[\"nalysis\",FontWeight->\"Bold\"]\)\>\"", ",", 
           "\"\<linear regression, nonlinear regression, generalized linear \
models including logit and probit, ANOVA\>\""}], "}"}]}], "}"}], "]"}]}], 
     "]"}], ";"}], "\[IndentingNewLine]", "*)"}], 
  "\[IndentingNewLine]"}]], "Input",ExpressionUUID->"bb871b44-c009-4883-bb3a-\
9230d31937bb"],

Cell[BoxData[
 RowBox[{"(*", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"MapThread", "[", 
    RowBox[{"OverviewMouseover", ",", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "\"\<ProbabilityDistribution\>\"", ",", 
          "\"\<defined by a PDF or other characteristic and the support of \
the distribution\>\""}], "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<TransformedDistribution\>\"", ",", 
          "\"\<distribution of a functional transformation of one or more \
random variates\>\""}], "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<TruncatedDistribution\>\"", ",", 
          "\"\<distribution with support truncated above or below and \
rescaled to have probability 1\>\""}], "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<CensoredDistribution\>\"", ",", 
          "\"\<distribution with upper and lower tail probabilities \
concentrated at defined censoring points\>\""}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<OrderDistribution\>\"", ",", 
          "\"\<distribution of the \
\!\(TraditionalForm\`\*SuperscriptBox[\(k\), \(th\)]\) order statistic for a \
sample of size \!\(TraditionalForm\`n\)\>\""}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<MixtureDistribution\>\"", ",", 
          "\"\<component mixture distribution\>\""}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<ParameterMixtureDistribution\>\"", ",", 
          "\"\<parametric mixture distribution\>\""}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<ProductDistribution\>\"", ",", 
          "\"\<multivariate distribution with independent components defined \
by distributions of the components\>\""}], "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<MarginalDistribution\>\"", ",", 
          "\"\<lower dimensional distribution obtained from a multivariate \
distribution\>\""}], "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<CopulaDistribution\>\"", ",", 
          "\"\<multivariate distribution defined by marginal distributions \
and a kernel that defines how they are combined\>\""}], "}"}]}], 
       "\[IndentingNewLine]", "}"}], "]"}]}], "]"}], ";"}], 
  "\[IndentingNewLine]", "*)"}]], "Input",ExpressionUUID->"406d20e9-6f97-49e2-\
acf9-a2f61d6920bb"],

Cell[BoxData[
 RowBox[{"(*", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"MapThread", "[", 
    RowBox[{"OverviewMouseover", ",", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<LinearModelFit\>\"", ",", "\"\<linear regression\>\""}],
          "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<LogitModelFit\>\"", ",", "\"\<logistic regression\>\""}], "}"}],
         ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"\"\<ProbitModelFit\>\"", ",", "\"\<probit regression\>\""}],
          "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<GeneralizedLinearModelFit\>\"", ",", 
          "\"\<generalized linear models with specified distributional \
structures and links\>\""}], "}"}]}], "\[IndentingNewLine]", "}"}], "]"}]}], 
    "]"}], ";"}], "\[IndentingNewLine]", "*)"}]], "Input",ExpressionUUID->\
"fd4e0882-5fe1-4a8c-aa06-57e57e867c65"]
}, Closed]],

Cell[CellGroupData[{

Cell["FillToLinePlot", "MoreExamplesSection",ExpressionUUID->"755eb2ad-41cb-45a4-a861-0df09a5252c1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FillToLinePlot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"f1_", ",", "lab1_"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"f2_", ",", "lab2_"}], "}"}], ",", "val_", ",", 
    RowBox[{"{", 
     RowBox[{"var_", ",", "min_", ",", "max_"}], "}"}]}], "]"}], ":=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Max", "[", 
       RowBox[{"val", ",", "f1"}], "]"}], ",", 
      RowBox[{"Max", "[", 
       RowBox[{"val", ",", "f2"}], "]"}], ",", 
      RowBox[{"Tooltip", "[", 
       RowBox[{"f1", ",", "lab1"}], "]"}], ",", 
      RowBox[{"Tooltip", "[", 
       RowBox[{"f2", ",", "lab2"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "min", ",", "max"}], "}"}], ",", 
    RowBox[{"Epilog", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Thick", ",", "Dashed", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"min", ",", "val"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"max", ",", "val"}], "}"}]}], "}"}], "]"}]}], "}"}], 
      "}"}]}], ",", 
    RowBox[{"Filling", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"1", "\[Rule]", "val"}], ",", 
       RowBox[{"2", "\[Rule]", "val"}]}], "}"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"ColorData", "[", 
        RowBox[{"1", ",", "1"}], "]"}], ",", 
       RowBox[{"ColorData", "[", 
        RowBox[{"1", ",", "2"}], "]"}]}], "}"}]}]}], "]"}]}]], "Input",Express\
ionUUID->"14bfced7-13df-4601-909c-9c7882dbf198"]
}, Closed]],

Cell[CellGroupData[{

Cell["Graphics Options", "MoreExamplesSection",
 CellChangeTimes->{
  3.537698282905027*^9},ExpressionUUID->"10d39ad1-adf4-409d-a84d-\
f3da55140109"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"ListPlot", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PlotStyle", "\[Rule]", " ", 
       RowBox[{"PointSize", "[", "Medium", "]"}]}], ",", 
      RowBox[{"ImageSize", "\[Rule]", " ", "Large"}]}], "}"}]}], "]"}], 
  ";"}]], "Input",ExpressionUUID->"10f4edc4-ea6b-4401-9fea-e942ae1557b4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"ListPointPlot3D", ",", 
    RowBox[{"PlotStyle", "\[Rule]", " ", 
     RowBox[{"PointSize", "[", "Medium", "]"}]}]}], "]"}], ";"}]], "Input",Exp\
ressionUUID->"03ef0326-ec8d-43f5-aead-e1699c3966f8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"DiscretePlot", ",", 
    RowBox[{"PlotStyle", "\[Rule]", " ", 
     RowBox[{"PointSize", "[", "Medium", "]"}]}]}], "]"}], ";"}]], "Input",Exp\
ressionUUID->"b02131b9-62b6-43a8-a70b-1cf9be85d018"]
}, Closed]],

Cell[CellGroupData[{

Cell["Load Packages", "MoreExamplesSection",
 CellChangeTimes->{{3.537698274809126*^9, 
  3.537698277360948*^9}},ExpressionUUID->"37ba1e73-9212-484c-9920-\
1cfd6cc510e5"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<HierarchicalClustering`\>\"", "]"}]], "Input",Expr\
essionUUID->"77bef564-b93a-4dce-9911-300ff20a23f4"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<ANOVA`\>\"", "]"}]], "Input",ExpressionUUID->"663eb5d1-88ad-4aa6-91a5-1dc555ff3744"]
}, Closed]],

Cell[CellGroupData[{

Cell["Set Working Directory", "MoreExamplesSection",
 CellChangeTimes->{{3.537698267412937*^9, 
  3.537698271137801*^9}},ExpressionUUID->"9aef5ff7-a0ce-4dc4-9093-\
be43d0d97029"],

Cell[BoxData[
 RowBox[{"SetDirectory", "[", 
  RowBox[{"FileNameJoin", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"NotebookDirectory", "[", "]"}], ",", "\"\<Data\>\""}], "}"}], 
   "]"}], "]"}]], "Input",ExpressionUUID->"2e24f237-4974-4e99-a0b7-\
41a34682593f"]
}, Closed]],

Cell[CellGroupData[{

Cell["Lastly", "MoreExamplesSection",ExpressionUUID->"35317706-9a76-4df4-a8b1-86df5f9d1416"],

Cell[BoxData[
 RowBox[{
  RowBox[{"$Line", "=", "0"}], ";"}]], "Input",ExpressionUUID->"0ff49f10-cdf1-4107-87b2-bfd8c3ab048f"]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
ScreenStyleEnvironment->"SlideShow",
WindowToolbars->{},
WindowSize->{1024, 768},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"Statistics: Model Fitting",
TaggingRules->{
 "CoursewareToolsSettings" -> {
   "$RecordNBMargins" -> Automatic, "$RecordNBSize" -> Automatic, 
    "$ControlPaletteNBMargins" -> Automatic, "$ControlPaletteType" -> 
    "Rectangular", "$ControlPaletteRecordingConfigType" -> "Rectangular", 
    "$ScriptNBMargins" -> Automatic, "$ScriptNBHeight" -> Automatic, 
    "$ConfigureImageDevicesAtStartup" -> False, "$UsageTimeToFade" -> 
    Automatic, "$RecordWithThinkpointsCheckPoints" -> True, 
    "$AutoAdvanceScript" -> False}, 
  "PresenterSettings" -> {
   "SideNotesPalette" -> {"PaletteNumber" -> 0}, "ShowNavigationBar" -> True},
   "DocuToolsSettingsInternal" -> {
   "$PacletVersion" -> "0.9.2083", "$MVersion" -> "11.3", "$FlaggedVersion" -> 
    11.2}},
FrontEndVersion->"11.3 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 5, \
2018)",
StyleDefinitions->Notebook[{
   Cell[
    CellGroupData[{
      Cell[
       TextData[{"Style Definitions for \n", 
         StyleBox["Wolfram Seminars", FontSlant -> "Italic"]}], "Subtitle"], 
      Cell[
       StyleData[StyleDefinitions -> "Default.nb"]], 
      Cell[
       StyleData[StyleDefinitions -> "StyleMenuClear.nb"]], 
      Cell[
       CellGroupData[{
         Cell["Style Environment Definitions", "Section"], 
         Cell[
          StyleData[
          All, "SlideShow", StyleDefinitions -> 
           StyleData[All, "Presentation"]], PageWidth -> WindowWidth, 
          DockedCells -> Cell[
            BoxData[
             GridBox[{{
                TooltipBox[
                 ButtonBox[
                  StyleBox[
                   RowBox[{"  ", "\[EmptySquare]", " "}], FontSize -> 20, 
                   GrayLevel[0.7]], Appearance -> None, 
                  ButtonFunction :> (
                   FEPrivate`NotebookToggleFullScreen[]; {}), Evaluator -> 
                  None], 
                 DynamicBox[
                  FEPrivate`FrontEndResource[
                  "SlideshowToolbarText", "TooltipToggleFullScreen"]]], 
                StyleBox[
                 RowBox[{
                   TooltipBox[
                    ButtonBox[
                    StyleBox[
                    RowBox[{" ", "\[FirstPage]", " "}], FontSize -> 25, 
                    GrayLevel[0.7]], ButtonData -> "ScrollPageFirst", 
                    Appearance -> None], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipFirstSlide"]]], 
                   "\[InvisibleSpace]", 
                   TooltipBox[
                    ButtonBox[
                    StyleBox[
                    RowBox[{" ", "\[LeftPointer]", " "}], FontSize -> 25, 
                    GrayLevel[0.7]], ButtonData -> "ScrollPagePrevious", 
                    Appearance -> None], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipPreviousSlide"]]], 
                   "\[InvisibleSpace]", 
                   TooltipBox[
                    ButtonBox[
                    StyleBox[
                    RowBox[{" ", "\[RightPointer]", " "}], FontSize -> 25, 
                    GrayLevel[0.7]], ButtonData -> "ScrollPageNext", 
                    Appearance -> None], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipNextSlide"]]], 
                   "\[InvisibleSpace]", 
                   TooltipBox[
                    ButtonBox[
                    StyleBox[
                    RowBox[{" ", "\[LastPage]", " "}], FontSize -> 25, 
                    GrayLevel[0.7]], ButtonData -> "ScrollPageLast", 
                    Appearance -> None], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipLastSlide"]]]}], 
                 ButtonBoxOptions -> {Alignment -> {Automatic, 
                    FEPrivate`If[
                    FEPrivate`SameQ[
                    FEPrivate`$OperatingSystem, "Unix"], -0.4, -0.5]}, 
                   Appearance -> "Palette", 
                   ButtonFunction :> (FEPrivate`FrontEndExecute[
                    FrontEnd`FrontEndToken[
                    FrontEnd`ButtonNotebook[], #]]& ), Evaluator -> None, 
                   FrameMargins -> 0, ImageMargins -> 0, ImageSize -> 
                   Medium}], 
                
                DynamicModuleBox[{$CellContext`cells$$ = {}, \
$CellContext`tagFind$$ = False}, 
                 TagBox[
                  DynamicBox[
                   PopupMenuBox[
                    Dynamic[
                    0, With[{$CellContext`nb$ = ButtonNotebook[]}, 
                    SelectionMove[$CellContext`nb$, Before, Notebook, 
                    AutoScroll -> False]; If[$CellContext`tagFind$$, 
                    Do[
                    
                    NotebookFind[$CellContext`nb$, "SlideShowHeader", Next, 
                    CellTags, AutoScroll -> False], {#}], 
                    Do[
                    
                    NotebookFind[$CellContext`nb$, "SlideShowNavigationBar", 
                    Next, CellStyle, AutoScroll -> False], {#}]]; 
                    SelectionMove[$CellContext`nb$, After, Cell, AutoScroll -> 
                    False]; NotebookWrite[$CellContext`nb$, 
                    Cell["", Deletable -> True, ShowCellBracket -> False], 
                    All]; NotebookDelete[$CellContext`nb$]; 
                    SelectionMove[$CellContext`nb$, 
                    If[$CellContext`tagFind$$, Previous, Next], 
                    Cell]]& ], $CellContext`cells$$, 
                    StyleBox[
                    RowBox[{
                    DynamicBox[
                    CurrentValue[{"CounterValue", "SlideShowNavigationBar"}]], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "SlideshowToolbarCounterText"]], 
                    DynamicBox[
                    
                    CurrentValue[{
                    "MaxCounterValue", "SlideShowNavigationBar"}]]}], 
                    "ControlStyle"], Appearance -> None, ImageSize -> 
                    Automatic], ImageSizeCache -> {50., {6., 18.}}], 
                  EventHandlerTag[{
                   "MouseDown" :> 
                    Module[{$CellContext`cnt$, $CellContext`nb$ = 
                    InputNotebook[]}, $CellContext`cells$$ = {}; \
$CellContext`cnt$ = Apply[(
                    NotebookFind[$CellContext`nb$, #, All, #2, AutoScroll -> 
                    False]; CurrentValue[$CellContext`nb$, {
                    "CellCount", True}])& , {{
                    "SlideShowNavigationBar", CellStyle}, {
                    "SlideShowHeader", CellTags}}, {1}]; $CellContext`cnt$ = 
                    Apply[If[$CellContext`tagFind$$ = # == 
                    0, #2, #]& , $CellContext`cnt$]; 
                    SelectionMove[$CellContext`nb$, Before, Notebook, 
                    AutoScroll -> False]; 
                    If[$CellContext`tagFind$$, $CellContext`cells$$ = 
                    Map[# -> StringJoin["Slide ", 
                    ToString[#]]& , 
                    Range[$CellContext`cnt$]], 
                    Do[NotebookFind[$CellContext`nb$, 
                    "SlideShowNavigationBar", Next, CellStyle, AutoScroll -> 
                    False]; SelectionMove[$CellContext`nb$, Next, Cell, 
                    AutoScroll -> False]; AppendTo[$CellContext`cells$$, 
                    ReplaceAll[
                    NotebookRead[$CellContext`nb$], Pattern[$CellContext`s, 
                    Blank[StyleBox]] :> With[{$CellContext`ss = Join[
                    Take[$CellContext`s, 1], 
                    DeleteCases[
                    Rest[$CellContext`s], 
                    Alternatives[
                    Blank[String], 
                    Blank[][FontColor, 
                    Blank[]]]]]}, 
                    
                    Condition[$CellContext`ss, 
                    True]]]], {$CellContext`cnt$}]; $CellContext`cells$$ = 
                    Replace[
                    Part[$CellContext`cells$$, All, 1], {BoxData[
                    Pattern[$CellContext`c, 
                    Blank[]]] :> $CellContext`c, TextData[
                    Pattern[$CellContext`c, 
                    Blank[]]] :> RowBox[
                    If[
                    
                    ListQ[$CellContext`c], $CellContext`c, \
{$CellContext`c}]]}, 1]; $CellContext`cells$$ = 
                    Thread[Range[$CellContext`cnt$] -> \
$CellContext`cells$$]]], PassEventsDown -> True, EvaluationOrder -> Before, 
                    PassEventsDown -> Automatic, PassEventsUp -> True}]], 
                 DynamicModuleValues :> {}]}}, AutoDelete -> False, 
              GridBoxItemSize -> {"Columns" -> {Automatic, Fit, Automatic}}]],
             "DockedCell", CellDynamicExpression :> If[CurrentValue[
                EvaluationNotebook[], {TaggingRules, "DisableController"}] === 
              True, Null, 
              (FrontEndExecute[
               FrontEnd`FrontEndToken[
                FrontEnd`InputNotebook[], #]]& )[
               Switch[
                ControllerState["Apple IR", {"B1", "B2"}], {True, 
                 Blank[]}, "ScrollPagePrevious", {
                 Blank[], True}, "ScrollPageNext", 
                Blank[], None]]], Magnification -> 0.75], 
          ScrollingOptions -> {
           "PagewiseDisplay" -> True, "VerticalScrollRange" -> Fit}, 
          ShowGroupOpener -> False, MenuSortingValue -> 1300], 
         Cell[
          StyleData["DockedCell"], Editable -> False, Evaluator -> "Local", 
          PageWidth -> WindowWidth, CellFrame -> {{0, 0}, {0, 0}}, 
          ShowSelection -> True, CellMargins -> {{0, 0}, {0, 0}}, 
          CellElementSpacings -> {
           "ClosedCellHeight" -> 0, "ClosedGroupTopMargin" -> 0}, 
          DynamicUpdating -> True, CellFrameMargins -> {{0, 0}, {0, 4}}, 
          ContextMenu -> None, ComponentwiseContextMenu -> {}, 
          ShowStringCharacters -> False, LineBreakWithin -> False, 
          Magnification -> 1, Background -> GrayLevel[0.97], 
          TooltipBoxOptions -> {TooltipDelay -> Automatic}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Headings", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Title"], MenuSortingValue -> 1, MenuCommandKey -> "1",
              FontFamily -> "Georgia", FontSize -> 36, FontWeight -> Plain, 
             FontColor -> RGBColor[0.796078, 0.0705882, 0]], 
            Cell[
             StyleData["Title", "Presentation"], 
             CellMargins -> {{90, 100}, {10, 100}}, FontSize -> 54], 
            Cell[
             StyleData["Title", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subtitle"], MenuSortingValue -> 100, MenuCommandKey -> 
             "2", FontFamily -> "Georgia", FontSize -> 24, FontWeight -> 
             "Plain", FontSlant -> "Italic"], 
            Cell[
             StyleData["Subtitle", "Presentation"], 
             CellMargins -> {{90, 100}, {100, 20}}, FontSize -> 32], 
            Cell[
             StyleData["Subtitle", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubtitle"], MenuSortingValue -> 200, 
             MenuCommandKey -> "3", FontFamily -> "Georgia", FontSize -> 20, 
             FontWeight -> "Plain", FontSlant -> "Italic", FontColor -> 
             GrayLevel[0.2]], 
            Cell[
             StyleData["Subsubtitle", "Presentation"], 
             CellMargins -> {{90, 20}, {2, 120}}, LineSpacing -> {1.25, 1}, 
             FontSize -> 26], 
            Cell[
             StyleData["Subsubtitle", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DateSection"], CellMargins -> {{30, 0}, {12, 24}}, 
             ShowStringCharacters -> False], 
            Cell[
             StyleData["DateSection", "Presentation"], 
             CellMargins -> {{90, 20}, {2, 36}}, ShowStringCharacters -> 
             False, FontSize -> 21], 
            Cell[
             StyleData["DateSection", "SlideShow"]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Sections", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Chapter"], CellMargins -> {{27, Inherited}, {8, 34}}, 
             CounterIncrements -> {"Chapter"}, MenuSortingValue -> 2410, 
             FontFamily -> "Georgia", FontSize -> 28, FontColor -> 
             RGBColor[0.811765, 0.117647, 0.145098], CellTags -> "Chapter"], 
            Cell[
             StyleData["Chapter", "Presentation"], CellFrame -> None, 
             CellMargins -> {{80, 60}, {20, 30}}, FontSize -> 36], 
            Cell[
             StyleData["Chapter", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "LargeChapter", StyleDefinitions -> StyleData["Chapter"]], 
             CellMargins -> {{27, Inherited}, {8, 34}}, MenuSortingValue -> 
             2430, FontFamily -> "Georgia", FontSize -> 30, FontColor -> 
             RGBColor[0.811765, 0.117647, 0.145098]], 
            Cell[
             StyleData["LargeChapter", "Presentation"], 
             CellMargins -> {{100, 100}, {10, 150}}, FontSize -> 54], 
            Cell[
             StyleData["LargeChapter", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Section"], CellFrame -> 0, MenuSortingValue -> 1200, 
             MenuCommandKey -> "4", FontFamily -> "Georgia", FontSize -> 24, 
             FontWeight -> Plain, FontColor -> 
             RGBColor[0.811765, 0.117647, 0.145098]], 
            Cell[
             StyleData["Section", "Presentation"], CellFrame -> None, 
             CellMargins -> {{80, 14}, {30, 30}}, FontFamily -> "Georgia", 
             FontSize -> 34, FontWeight -> Plain, FontColor -> 
             RGBColor[0.811765, 0.117647, 0.145098]], 
            Cell[
             StyleData["Section", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsection"], CellDingbat -> "\[RightGuillemet]", 
             CellGroupingRules -> {"SectionGrouping", 40}, MenuSortingValue -> 
             1300, MenuCommandKey -> "5", FontFamily -> "Georgia", FontSize -> 
             22, FontWeight -> "Bold", FontColor -> GrayLevel[0.25]], 
            Cell[
             StyleData["Subsection", "Presentation"], 
             CellMargins -> {{84, 60}, {12, 20}}, FontSize -> 25], 
            Cell[
             StyleData["Subsection", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubsection"], CellDingbat -> "\[RightGuillemet]", 
             MenuSortingValue -> 1400, MenuCommandKey -> "6", FontFamily -> 
             "Georgia", FontSize -> 20, FontWeight -> "Plain", FontColor -> 
             GrayLevel[0.3]], 
            Cell[
             StyleData["Subsubsection", "Presentation"], 
             CellMargins -> {{88, 60}, {0, 12}}, FontSize -> 22], 
            Cell[
             StyleData["Subsubsection", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "MoreExamplesSection", StyleDefinitions -> 
              StyleData["Subsubsection"]], CellDingbat -> None, 
             ShowGroupOpener -> True, 
             CellGroupingRules -> {"SectionGrouping", 45}, MenuSortingValue -> 
             2100, FontWeight -> "Plain", FontColor -> 
             RGBColor[0.636862, 0.0564706, 0.]], 
            Cell[
             StyleData["MoreExamplesSection", "Presentation"], 
             CellMargins -> {{88, 60}, {20, 12}}], 
            Cell[
             StyleData["MoreExamplesSection", "SlideShow"], 
             CellMargins -> {{88, 60}, {20, 12}}, FontWeight -> 
             "Plain", $CellContext`WholeCellGroupOpener -> True]}, Closed]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Text", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Text"], MenuSortingValue -> 2000, MenuCommandKey -> 
             "7", FontFamily -> "Georgia", FontSize -> 18], 
            Cell[
             StyleData["Text", "Presentation"], 
             CellMargins -> {{80, 20}, {12, 12}}, LineSpacing -> {1.25, 1}, 
             FontFamily -> "Georgia", FontSize -> 20], 
            Cell[
             StyleData["Text", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["MathCaption"], MenuSortingValue -> 2010, 
             MenuCommandKey -> "8", FontFamily -> "Georgia", FontSize -> 18, 
             FontColor -> GrayLevel[0]], 
            Cell[
             StyleData["MathCaption", "Presentation"], 
             CellMargins -> {{120, 12}, {6, 34}}, LineSpacing -> {1.25, 1}, 
             FontSize -> 20], 
            Cell[
             StyleData["MathCaption", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "IntegrationMathCaption", StyleDefinitions -> 
              StyleData["MathCaption"]], CellMargins -> {{0, 12}, {2, 24}}, 
             CellFrameMargins -> {{0, 0}, {0, 3}}, CellFrameLabels -> {{
                PaneBox[
                 FrameBox[
                  StyleBox[
                  "Integration", FontFamily -> "Helvetica", FontSize -> 9, 
                   FontColor -> GrayLevel[1], FontWeight -> Plain], 
                  Background -> RGBColor[0.811765, 0.117647, 0.145098], 
                  BoxFrame -> 0, FrameStyle -> None, 
                  FrameMargins -> {{3, 3}, {1, 1}}], ImageSize -> 56, 
                 Alignment -> Left, FrameMargins -> 0], None}, {None, None}}], 
            Cell[
             StyleData["IntegrationMathCaption", "Presentation"], 
             CellMargins -> {{30, 12}, {12, 12}}, 
             CellFrameMargins -> {{10, 0}, {0, 5}}, FontSize -> 20], 
            Cell[
             StyleData["IntegrationMathCaption", "SlideShow"], 
             CellMargins -> {{30, 12}, {12, 12}}, 
             CellFrameMargins -> {{10, 0}, {0, 5}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "AutomationMathCaption", StyleDefinitions -> 
              StyleData["IntegrationMathCaption"]], 
             CellMargins -> {{0, 12}, {2, 24}}, 
             CellFrameMargins -> {{0, 0}, {0, 3}}, CellFrameLabels -> {{
                PaneBox[
                 FrameBox[
                  StyleBox[
                  "Automation", FontFamily -> "Helvetica", FontSize -> 9, 
                   FontColor -> GrayLevel[1], FontWeight -> Plain], 
                  Background -> RGBColor[0.811765, 0.117647, 0.145098], 
                  BoxFrame -> 0, FrameStyle -> None, 
                  FrameMargins -> {{3, 3}, {1, 1}}], ImageSize -> 56, 
                 Alignment -> Left, FrameMargins -> 0], None}, {None, None}}], 
            Cell[
             StyleData["AutomationMathCaption", "Presentation"], 
             CellMargins -> {{30, 12}, {12, 12}}, FontSize -> 20], 
            Cell[
             StyleData["AutomationMathCaption", "SlideShow"], 
             CellMargins -> {{30, 12}, {12, 12}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Comment", StyleDefinitions -> StyleData["Text"]], 
             CellMargins -> {{0, 12}, {2, 24}}, 
             CellFrameMargins -> {{0, 0}, {0, 3}}, CellFrameLabels -> {{
                PaneBox[
                 FrameBox[
                  StyleBox[
                  "Comment", FontFamily -> "Helvetica", FontSize -> 9, 
                   FontColor -> GrayLevel[1], FontWeight -> Plain], 
                  Background -> RGBColor[1., 0.647059, 0], BoxFrame -> 1, 
                  FrameStyle -> RGBColor[1., 0.647059, 0], 
                  FrameMargins -> {{3, 3}, {1, 1}}], ImageSize -> 56, 
                 Alignment -> Left, FrameMargins -> 0], None}, {None, None}}, 
             MenuSortingValue -> 2200, FontSize -> 14], 
            Cell[
             StyleData["Comment", "Presentation"], 
             CellMargins -> {{30, 12}, {12, 12}}, FontSize -> 16], 
            Cell[
             StyleData["Comment", "SlideShow"], 
             CellMargins -> {{30, 12}, {12, 12}}, FontSize -> 16]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DisplayFormula"], 
             CellMargins -> {{60, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultInputFormatType, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, LanguageCategory -> 
             "Formula", ScriptLevel -> 0, SingleLetterItalics -> True, 
             MenuSortingValue -> 1700, 
             UnderoverscriptBoxOptions -> {
              LimitsPositioning -> True}, $CellContext`StripStyleOnPaste -> 
             True], 
            Cell[
             StyleData["DisplayFormula", "Presentation"], 
             CellMargins -> {{120, Inherited}, {
               1.75 Inherited, 1.75 Inherited}}, LineSpacing -> {1, 5}, 
             FontFamily -> "Georgia", FontSize -> 20], 
            Cell[
             StyleData["DisplayFormula", "SlideShow"]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Items", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Item"], CellDingbat -> "\[RightGuillemet] ", 
             LineSpacing -> {1.5, 0}, MenuSortingValue -> 2700, FontFamily -> 
             "Georgia", FontSize -> 18, FontColor -> GrayLevel[0.2]], 
            Cell[
             StyleData["Item", "Presentation"], 
             CellMargins -> {{116, 20}, {12, 12}}, FontFamily -> "Georgia", 
             FontSize -> 20], 
            Cell[
             StyleData["Item", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ItemParagraph"], MenuSortingValue -> 2710, FontFamily -> 
             "Georgia", FontSize -> 18, FontColor -> GrayLevel[0.2]], 
            Cell[
             StyleData["ItemParagraph", "Presentation"], 
             CellMargins -> {{120, 90}, {12, 12}}, LineSpacing -> {1.25, 0}, 
             FontFamily -> "Georgia", FontSize -> 20], 
            Cell[
             StyleData["ItemParagraph", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ItemNumbered"], LineSpacing -> {1.5, 0}, 
             MenuSortingValue -> 2720, FontFamily -> "Georgia", FontSize -> 
             18, FontColor -> GrayLevel[0.25]], 
            Cell[
             StyleData["ItemNumbered", "Presentation"], 
             CellMargins -> {{116, 20}, {12, 12}}, FontFamily -> "Georgia", 
             FontSize -> 20], 
            Cell[
             StyleData["ItemNumbered", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subitem"], CellDingbat -> "\[RightGuillemet] ", 
             LineSpacing -> {1.5, 0}, MenuSortingValue -> 2730, FontFamily -> 
             "Georgia", FontSize -> 16, FontColor -> GrayLevel[0.3]], 
            Cell[
             StyleData["Subitem", "Presentation"], 
             CellMargins -> {{136, 20}, {10, 10}}, FontFamily -> "Georgia", 
             FontSize -> 21], 
            Cell[
             StyleData["Subitem", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SubitemParagraph"], LineSpacing -> {1.5, 0}, 
             MenuSortingValue -> 2740, FontFamily -> "Georgia", FontSize -> 
             16, FontColor -> GrayLevel[0.3]], 
            Cell[
             StyleData["SubitemParagraph", "Presentation"], 
             CellMargins -> {{136, 90}, {10, 8}}, FontFamily -> "Georgia", 
             FontSize -> 18], 
            Cell[
             StyleData["SubitemParagraph", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SubitemNumbered"], LineSpacing -> {1.5, 0}, 
             MenuSortingValue -> 2750, FontFamily -> "Georgia", FontSize -> 
             16, FontColor -> GrayLevel[0.3]], 
            Cell[
             StyleData["SubitemNumbered", "Presentation"], 
             CellMargins -> {{136, 20}, {10, 10}}, FontFamily -> "Georgia", 
             FontSize -> 18], 
            Cell[
             StyleData["SubitemNumbered", "SlideShow"]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Input and Output", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Input"], MenuSortingValue -> 2020, MenuCommandKey -> 
             "9", FontSize -> 18], 
            Cell[
             StyleData["Input", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["Input", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["CellLabel"], 
             CellLabelMargins -> {{12, Inherited}, {Inherited, Inherited}}, 
             LanguageCategory -> None, StyleMenuListing -> None, FontFamily -> 
             "Helvetica", FontSize -> 9, FontColor -> 
             RGBColor[0.269993, 0.308507, 0.6]], 
            Cell[
             StyleData["CellLabel", "Presentation"], 
             CellMargins -> {{12, Inherited}, {1.5 Inherited, 1.5 Inherited}},
              FontSize -> 12], 
            Cell[
             StyleData["CellLabel", "SlideShow"], 
             CellMargins -> {{12, Inherited}, {1.5 Inherited, 1.5 Inherited}},
              FontSize -> 12]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["WolframAlphaShort"], FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaShort", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaShort", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["WolframAlphaShortInput"], FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaShortInput", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaShortInput", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["WolframAlphaLong"], FontFamily -> "Helvetica", 
             FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaLong", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaLong", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["WolframAlphaLongInput"], FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaLongInput", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaLongInput", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Output"], MenuSortingValue -> 2030, FontSize -> 18], 
            Cell[
             StyleData["Output", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["Output", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Print"], FontSize -> 18], 
            Cell[
             StyleData["Print", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["Print", "SlideShow"]]}, Closed]], 
         Cell[
          StyleData["MSG"], FontSize -> 16]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles of Links", "Section"], 
         Cell[
          StyleData["Link", "SlideShow"]], 
         Cell[
          StyleData["SearchLink", StyleDefinitions -> StyleData["Link"]]], 
         Cell[
          StyleData["FunctionLink"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Special Styles", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Picture"], CellMargins -> {{100, 100}, {20, 20}}, 
             ShowStringCharacters -> False, MenuSortingValue -> 5000, 
             Magnification -> 1], 
            Cell[
             StyleData["Picture", "Presentation"], 
             CellMargins -> {{100, 100}, {20, 20}}, Magnification -> 1], 
            Cell[
             StyleData["Picture", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "PictureCaption", StyleDefinitions -> StyleData["Text"]], 
             CellDingbat -> "\[FilledUpTriangle]", 
             CellMargins -> {{114, 100}, {15, 4}}, ShowStringCharacters -> 
             False, MenuSortingValue -> 5100, FontSize -> 14, FontColor -> 
             GrayLevel[0.3]], 
            Cell[
             StyleData["PictureCaption", "Presentation"], 
             CellMargins -> {{114, 100}, {20, 0}}, FontSize -> 16], 
            Cell[
             StyleData["PictureCaption", "SlideShow"], 
             CellMargins -> {{114, 100}, {20, 0}}, FontFamily -> "Helvetica", 
             FontSize -> 17]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["OverviewTitle"], CellFrame -> None, 
             CellMargins -> {{100, 100}, {20, 60}}, FontFamily -> "Calibri", 
             FontSize -> 24, FontWeight -> "Bold", FontColor -> 
             GrayLevel[0.4]], 
            Cell[
             StyleData["OverviewTitle", "Presentation"], CellFrame -> None, 
             CellMargins -> {{100, 100}, {20, 60}}, FontFamily -> "Calibri", 
             FontSize -> 24, FontWeight -> "Bold", FontColor -> 
             GrayLevel[0.4]], 
            Cell[
             StyleData["OverviewTitle", "SlideShow"], CellFrame -> None, 
             CellMargins -> {{100, 100}, {20, 60}}, FontFamily -> "Calibri", 
             FontSize -> 24, FontWeight -> "Bold", FontColor -> 
             GrayLevel[0.4]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["OverviewSection"], CellFrame -> None, 
             CellMargins -> {{120, 100}, {10, 10}}, FontFamily -> "Georgia", 
             FontSize -> 22, FontWeight -> Plain, FontColor -> 
             RGBColor[
              0.811765, 0.117647, 
               0.145098], $CellContext`ReturnCreatesNewCell -> True], 
            Cell[
             StyleData["OverviewSection", "Presentation"], CellFrame -> None, 
             CellMargins -> {{120, 100}, {10, 10}}, FontFamily -> "Georgia", 
             FontSize -> 22, FontWeight -> Plain, FontColor -> 
             RGBColor[
              0.811765, 0.117647, 
               0.145098], $CellContext`ReturnCreatesNewCell -> True], 
            Cell[
             StyleData["OverviewSection", "SlideShow"], CellFrame -> None, 
             CellMargins -> {{120, 100}, {10, 10}}, FontFamily -> "Georgia", 
             FontSize -> 22, FontWeight -> Plain, FontColor -> 
             RGBColor[
              0.811765, 0.117647, 
               0.145098], $CellContext`ReturnCreatesNewCell -> True]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ChapterTagline"], CellMargins -> {{60, 90}, {15, 0}}, 
             MenuSortingValue -> 2420, FontFamily -> "Georgia", FontSize -> 
             20, FontWeight -> "Plain", FontSlant -> "Italic", FontColor -> 
             GrayLevel[0.3]], 
            Cell[
             StyleData["ChapterTagline", "Presentation"], 
             CellMargins -> {{90, 90}, {15, 0}}, FontSize -> 24], 
            Cell[
             StyleData["ChapterTagline", "SlideShow"]]}, Closed]], 
         Cell[
          StyleData["PlotLabel"], FontFamily -> "Helvetica", FontSize -> 14], 
         Cell[
          StyleData["NonPrintButton"], 
          CellMargins -> {{128, Inherited}, {16, 0}}, FontFamily -> 
          "Helvetica", FontSize -> 12, FontColor -> GrayLevel[1], 
          ButtonBoxOptions -> {
           Background -> RGBColor[0.811765, 0.117647, 0.145098], 
            ButtonMargins -> 4}], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Program"]], 
            Cell[
             StyleData["Program", "SlideShow"], 
             CellMargins -> {{116, 48}, {16, 16}}, FontSize -> 18]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Editorial"], ShowCellBracket -> Automatic, 
             CellMargins -> {{24, 10}, {6, 6}}, 
             CellBracketOptions -> {
              "Color" -> RGBColor[0.786999, 0.0386053, 0.0571756]}, 
             CellFrameLabels -> {{
                Cell[
                 TextData[{"Edit:"}], FontFamily -> "Helvetica", FontSize -> 
                 16, FontWeight -> "Bold", CellBaseline -> Baseline], None}, {
               None, None}}, DefaultNewInlineCellStyle -> "None", Hyphenation -> 
             True, LineSpacing -> {1, 3}, LanguageCategory -> 
             "NaturalLanguage", FontFamily -> "Helvetica", FontSize -> 19, 
             FontColor -> RGBColor[1, 0, 0]], 
            Cell[
             StyleData["Editorial", "SlideShow"], 
             CellMargins -> {{Inherited, Inherited}, {0, 0}}, 
             CellElementSpacings -> {
              "CellMinHeight" -> 1, "ClosedCellHeight" -> 0}, CellOpen -> 
             False]}, Closed]], 
         Cell[
          StyleData["DialogStyle"], FontSize -> 17], 
         Cell[
          StyleData["TooltipLabel"], CellFrame -> 1., CellFrameMargins :> 
          CurrentValue["TooltipFrameMargins"], CellFrameColor :> 
          CurrentValue[{"SystemColor", "TooltipFrame"}], TextAlignment -> 
          Left, TextJustification -> 0., ShowStringCharacters -> False, 
          FontFamily :> CurrentValue["TooltipFontFamily"], FontSize :> 
          CurrentValue["TooltipFontSize"], FontWeight -> "Plain", FontSlant -> 
          "Plain", Magnification -> 1.5, FontColor :> 
          CurrentValue[{"SystemColor", "TooltipText"}], FontOpacity -> 1., 
          Background :> CurrentValue[{"SystemColor", "Tooltip"}]]}, Open]]}, 
     Open]]}, Visible -> False, FrontEndVersion -> 
  "11.3 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 5, 2018)", 
  StyleDefinitions -> "StylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "SlideShowHeader"->{
  Cell[618, 23, 122, 2, 1, "SlideShowNavigationBar",ExpressionUUID->"40b2505a-7ad7-41c6-8278-7a767f68d928",
   CellTags->"SlideShowHeader"],
  Cell[1678, 54, 122, 2, 1, "SlideShowNavigationBar",ExpressionUUID->"5c7ca38e-9c31-48e8-8d24-f55be1c18e26",
   CellTags->"SlideShowHeader"],
  Cell[2503, 78, 122, 2, 1, "SlideShowNavigationBar",ExpressionUUID->"c0d3b38b-c7b2-4f5f-b5d5-91cdafc94a3d",
   CellTags->"SlideShowHeader"],
  Cell[6197, 193, 122, 2, 1, "SlideShowNavigationBar",ExpressionUUID->"6a5e94c0-3a2c-4ff2-b50d-126326259235",
   CellTags->"SlideShowHeader"],
  Cell[10137, 306, 122, 2, 1, "SlideShowNavigationBar",ExpressionUUID->"a929462d-4bc3-4e47-ad6f-decc9f054f39",
   CellTags->"SlideShowHeader"],
  Cell[21713, 631, 122, 2, 1, "SlideShowNavigationBar",ExpressionUUID->"694740b3-3650-4a98-8883-f98ba0660e36",
   CellTags->"SlideShowHeader"],
  Cell[29159, 839, 122, 2, 1, "SlideShowNavigationBar",ExpressionUUID->"9042abc9-59f3-47fb-a4f1-69481e50350d",
   CellTags->"SlideShowHeader"],
  Cell[38584, 1100, 122, 2, 1, "SlideShowNavigationBar",ExpressionUUID->"3dc8af74-6103-4cf4-a428-829d7fe3929d",
   CellTags->"SlideShowHeader"],
  Cell[41646, 1182, 122, 2, 1, "SlideShowNavigationBar",ExpressionUUID->"328e184d-66bb-41fa-842b-2820f6414c3e",
   CellTags->"SlideShowHeader"],
  Cell[47684, 1358, 122, 2, 1, "SlideShowNavigationBar",ExpressionUUID->"5a3339e5-e2b5-4d72-819c-dcd9f8812df8",
   CellTags->"SlideShowHeader"],
  Cell[52347, 1494, 122, 2, 1, "SlideShowNavigationBar",ExpressionUUID->"592ec17c-dfd2-4405-b64d-f747750d2a30",
   CellTags->"SlideShowHeader"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"SlideShowHeader", 103359, 2677}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[618, 23, 122, 2, 1, "SlideShowNavigationBar",ExpressionUUID->"40b2505a-7ad7-41c6-8278-7a767f68d928",
 CellTags->"SlideShowHeader"],
Cell[743, 27, 314, 5, 172, "Title",ExpressionUUID->"f071160a-c4b0-4a33-b851-ed9a2e790b08"],
Cell[1060, 34, 425, 10, 229, "Subsubtitle",ExpressionUUID->"a541018f-0547-4229-ad63-bec7c491a576"],
Cell[1488, 46, 153, 3, 43, "Input",ExpressionUUID->"f9f913ca-4c93-481d-ae7e-a7589c336be0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1678, 54, 122, 2, 1, "SlideShowNavigationBar",ExpressionUUID->"5c7ca38e-9c31-48e8-8d24-f55be1c18e26",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[1825, 60, 100, 0, 100, "Section",ExpressionUUID->"44aab477-e371-4e06-8dc5-de4dbcc9a941"],
Cell[1928, 62, 450, 8, 110, "Text",ExpressionUUID->"53bdaf84-c24f-4571-98f6-ac64c1002967"],
Cell[2381, 72, 73, 0, 20, "Spacer",ExpressionUUID->"4d7c7fdc-c1ee-46bd-87da-4c26a881e685"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2503, 78, 122, 2, 1, "SlideShowNavigationBar",ExpressionUUID->"c0d3b38b-c7b2-4f5f-b5d5-91cdafc94a3d",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[2650, 84, 166, 3, 100, "Section",ExpressionUUID->"d03d22c7-310b-4ac4-915d-286824303c5f"],
Cell[2819, 89, 122, 0, 48, "Text",ExpressionUUID->"ef311bae-dd47-4972-8d3c-88a918fadbec"],
Cell[2944, 91, 284, 7, 43, "Input",ExpressionUUID->"f00961f3-3a06-4827-a893-845feca519f0"],
Cell[3231, 100, 406, 11, 74, "MathCaption",ExpressionUUID->"63a8f2fc-19e4-4666-9573-599d1d7146eb"],
Cell[3640, 113, 508, 12, 43, "Input",ExpressionUUID->"b62e4533-40cc-4a83-a010-d7278e660aa1"],
Cell[4151, 127, 186, 4, 43, "Input",ExpressionUUID->"7d4c3927-97d5-4d41-8ee7-a3c21b09b2e1"],
Cell[4340, 133, 73, 0, 20, "Spacer",ExpressionUUID->"c6a7486a-7a54-4c65-8afd-f512d8918466"],
Cell[4416, 135, 575, 14, 86, "Text",ExpressionUUID->"b52ef9f3-7122-476f-bac8-5d82417bb256"],
Cell[4994, 151, 388, 11, 69, "MathCaption",ExpressionUUID->"757fa8e3-b6ce-4685-bab9-1f2b767478a3"],
Cell[5385, 164, 216, 5, 43, "Input",ExpressionUUID->"e333d078-20c9-4349-a5b5-e35e4f3cfd20"],
Cell[5604, 171, 263, 8, 69, "MathCaption",ExpressionUUID->"a2a26c37-2e42-4781-9a47-15544d5224f0"],
Cell[5870, 181, 202, 4, 43, "Input",ExpressionUUID->"10c75552-4c0c-44d0-93a2-e881518f0adb"],
Cell[6075, 187, 73, 0, 20, "Spacer",ExpressionUUID->"bd3d3f94-8845-4a4d-ac6d-a448727ff117"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[6197, 193, 122, 2, 1, "SlideShowNavigationBar",ExpressionUUID->"6a5e94c0-3a2c-4ff2-b50d-126326259235",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[6344, 199, 202, 3, 100, "Section",ExpressionUUID->"ad7c115b-a7d1-47b1-91f6-7bdca7f5b2a9"],
Cell[6549, 204, 232, 6, 48, "Text",ExpressionUUID->"0e73eb03-8ace-4de8-99af-e41053f45e6f"],
Cell[6784, 212, 172, 3, 67, "MathCaption",ExpressionUUID->"642398d9-7635-4929-b55b-3537cf26ff4a"],
Cell[6959, 217, 366, 10, 43, "Input",ExpressionUUID->"57720251-e7e2-452d-89f8-bf02dd34bcca"],
Cell[7328, 229, 414, 8, 98, "MathCaption",ExpressionUUID->"b320d315-6cb4-4746-a255-7b0e30ece406"],
Cell[7745, 239, 772, 16, 73, "Input",ExpressionUUID->"3c001d22-c88d-49e7-9210-4d18d379a4b8"],
Cell[8520, 257, 334, 7, 67, "MathCaption",ExpressionUUID->"6ac50df3-06da-4643-a262-cd60153cd666"],
Cell[8857, 266, 1155, 32, 102, "Input",ExpressionUUID->"900e72d2-c751-4241-8bd6-f248ac4a2da7"],
Cell[10015, 300, 73, 0, 20, "Spacer",ExpressionUUID->"1e22c0fb-0ece-4feb-addf-0c84f43580cf"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[10137, 306, 122, 2, 1, "SlideShowNavigationBar",ExpressionUUID->"a929462d-4bc3-4e47-ad6f-decc9f054f39",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[10284, 312, 204, 3, 100, "Section",ExpressionUUID->"9cb296b3-a4b0-4845-9415-b4fedeee3b0c"],
Cell[10491, 317, 318, 5, 48, "Text",ExpressionUUID->"fb9420ea-8592-4c73-a949-56f4a67faf0a"],
Cell[10812, 324, 958, 31, 52, "Text",ExpressionUUID->"78a9b329-f859-4f09-917c-b8c24f643d33"],
Cell[11773, 357, 1239, 38, 52, "Text",ExpressionUUID->"1bbd5019-3320-462d-8188-c62ab157c82e"],
Cell[13015, 397, 345, 5, 48, "Text",ExpressionUUID->"0b9316da-e24f-4806-b47e-54b4813fac7b"],
Cell[13363, 404, 1156, 37, 52, "Text",ExpressionUUID->"cf602463-7d64-4d82-8b49-5a1f885cd7a2"],
Cell[14522, 443, 1219, 33, 149, "Text",ExpressionUUID->"30c69640-5ae6-414a-a126-6a82c041ec90"],
Cell[15744, 478, 138, 1, 48, "Text",ExpressionUUID->"467b4121-d6d3-49d4-98b6-414ff8de0bf8"],
Cell[15885, 481, 1479, 35, 62, "OverviewSection",ExpressionUUID->"19910cf3-a36c-4726-ae5e-305ef872dbdd"],
Cell[17367, 518, 1325, 32, 62, "OverviewSection",ExpressionUUID->"32bfd67d-9240-439f-9b18-f94212d35e5f"],
Cell[18695, 552, 1325, 32, 62, "OverviewSection",ExpressionUUID->"e87215e2-ad78-4097-a889-906e7aa31e7d"],
Cell[20023, 586, 1408, 33, 62, "OverviewSection",ExpressionUUID->"006d5140-7b39-4ef6-bd06-40b65ff27909"],
Cell[21434, 621, 154, 2, 48, "Text",ExpressionUUID->"ff92bddf-04e1-467b-bb17-2e2d7adec4ed"],
Cell[21591, 625, 73, 0, 20, "Spacer",ExpressionUUID->"b6fe9a62-00a8-4e98-b1ea-829199fb0518"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[21713, 631, 122, 2, 1, "SlideShowNavigationBar",ExpressionUUID->"694740b3-3650-4a98-8883-f98ba0660e36",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[21860, 637, 214, 4, 100, "Section",ExpressionUUID->"908ac7a9-d82f-4aac-8446-e7ff27a64fd3"],
Cell[22077, 643, 930, 21, 124, "Text",ExpressionUUID->"fe7ae131-68a2-4d24-9c39-c65342ea5ce6"],
Cell[23010, 666, 247, 6, 67, "MathCaption",ExpressionUUID->"8b48fc1d-d959-499f-839f-a444fab02119"],
Cell[23260, 674, 669, 22, 66, "Input",ExpressionUUID->"e5476af2-0b82-4826-a213-a46eecb0ace4"],
Cell[23932, 698, 346, 5, 67, "MathCaption",ExpressionUUID->"7b929f0e-1204-44bd-a668-72ef39f11579"],
Cell[24281, 705, 339, 7, 43, "Input",ExpressionUUID->"f025e13f-e18a-4536-b0de-65d988580287"],
Cell[24623, 714, 318, 7, 67, "MathCaption",ExpressionUUID->"d4f1b107-b758-4649-ae10-05c2c68398b6"],
Cell[24944, 723, 343, 8, 43, "Input",ExpressionUUID->"e068b251-4d0e-4951-b53b-cf6fce662497"],
Cell[25290, 733, 73, 0, 20, "Spacer",ExpressionUUID->"46415ef7-f7fd-4257-ae6a-8742b82ecb76"],
Cell[25366, 735, 585, 14, 93, "Text",ExpressionUUID->"fe213759-d776-4607-89b8-e3bf3a8fe526"],
Cell[25954, 751, 190, 3, 67, "MathCaption",ExpressionUUID->"d3f793c9-9758-4b90-9e5b-5f7ad8a5659f"],
Cell[26147, 756, 265, 6, 43, "Input",ExpressionUUID->"7c67a60a-d944-4527-abd0-d0919c102dfc"],
Cell[26415, 764, 73, 0, 20, "Spacer",ExpressionUUID->"da22daa6-f0ec-4e41-a864-4e22b69b7cd5"],
Cell[26491, 766, 477, 12, 86, "Text",ExpressionUUID->"da5cb22a-26ca-462d-8783-156a25c1dae0"],
Cell[26971, 780, 261, 5, 67, "MathCaption",ExpressionUUID->"d38f4267-d186-4135-bfeb-633c5efee5be"],
Cell[27235, 787, 448, 10, 43, "Input",ExpressionUUID->"f1d3c3e0-4853-44a0-a2ba-2ff95ea75d55"],
Cell[27686, 799, 73, 0, 20, "Spacer",ExpressionUUID->"86ffebc5-56f6-4171-946f-c1b76270bbc6"],
Cell[27762, 801, 539, 13, 86, "Text",ExpressionUUID->"d88e78f2-2809-4f3c-86af-98b96b856c8a"],
Cell[28304, 816, 299, 4, 67, "MathCaption",ExpressionUUID->"1cbdec7d-2b00-4b1f-8db8-d0440659de23"],
Cell[28606, 822, 428, 9, 43, "Input",ExpressionUUID->"dc2e6ce1-228b-4d93-ac1d-b93b0150b6c3"],
Cell[29037, 833, 73, 0, 20, "Spacer",ExpressionUUID->"58cb542a-4997-4b0d-86d7-97cdd8a8c7a6"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[29159, 839, 122, 2, 1, "SlideShowNavigationBar",ExpressionUUID->"9042abc9-59f3-47fb-a4f1-69481e50350d",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[29306, 845, 209, 4, 100, "Section",ExpressionUUID->"99c5626b-9a7e-494c-bc95-30016cfcb1e0"],
Cell[29518, 851, 867, 21, 124, "Text",ExpressionUUID->"3576af3e-5881-4c02-b8ac-ac6fe11830ec"],
Cell[30388, 874, 385, 7, 79, "Text",ExpressionUUID->"768a7299-df79-4080-ba07-7751dd7137bc"],
Cell[30776, 883, 302, 4, 67, "MathCaption",ExpressionUUID->"af08bea6-45c9-43eb-9666-2e0eff63cff1"],
Cell[31081, 889, 1126, 29, 102, "Input",ExpressionUUID->"c63de1d6-b0ae-4f8c-b092-66093fb96f0a"],
Cell[32210, 920, 73, 0, 20, "Spacer",ExpressionUUID->"99964fc3-18be-42a6-856b-3cb61a9345bc"],
Cell[32286, 922, 488, 12, 55, "Text",ExpressionUUID->"3ccdacc2-c212-47df-88e2-89a0efb68b66"],
Cell[32777, 936, 330, 5, 67, "MathCaption",ExpressionUUID->"e4065297-2792-4fcb-9162-72d7b7cad0ae"],
Cell[33110, 943, 461, 10, 73, "Input",ExpressionUUID->"e2639372-e5a1-4a94-b5a4-9aebab8eb5d2"],
Cell[33574, 955, 73, 0, 20, "Spacer",ExpressionUUID->"c15bf097-8067-42c0-a9fb-d732edfcc02f"],
Cell[33650, 957, 768, 19, 93, "Text",ExpressionUUID->"cab80976-3fee-4d24-b58e-c0763e829b7c"],
Cell[34421, 978, 387, 12, 69, "MathCaption",ExpressionUUID->"c1de55b8-8b0e-4b2f-a3a0-ace378d90b09"],
Cell[34811, 992, 336, 9, 43, "Input",ExpressionUUID->"cc90ea2b-9dc5-4c5f-96e6-61436ced720b"],
Cell[35150, 1003, 73, 0, 20, "Spacer",ExpressionUUID->"37f931e8-580f-492f-ba82-ff88025ade51"],
Cell[35226, 1005, 299, 7, 48, "Text",ExpressionUUID->"d818fe19-323b-4188-88b0-b43f2971b4b4"],
Cell[35528, 1014, 193, 3, 67, "MathCaption",ExpressionUUID->"a052de68-cdcf-433e-a383-b6191a0b1f87"],
Cell[35724, 1019, 602, 14, 73, "Input",ExpressionUUID->"70c48c33-b48d-443e-b4bd-92850bc00c39"],
Cell[36329, 1035, 241, 5, 67, "MathCaption",ExpressionUUID->"f2af22ce-c16d-4b8f-8205-e9933dba8d6b"],
Cell[36573, 1042, 1095, 29, 102, "Input",ExpressionUUID->"1edc50d6-d3fa-407a-9850-c010b623d639"],
Cell[37671, 1073, 73, 0, 20, "Spacer",ExpressionUUID->"35db6bbc-2104-435e-983e-e455008c9eb8"],
Cell[37747, 1075, 712, 17, 86, "Text",ExpressionUUID->"3d396798-fce9-4add-93c5-55ec833b9ee1"],
Cell[38462, 1094, 73, 0, 20, "Spacer",ExpressionUUID->"76cc7ce4-9631-430a-b8dc-0e3c33a62b88"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[38584, 1100, 122, 2, 1, "SlideShowNavigationBar",ExpressionUUID->"3dc8af74-6103-4cf4-a428-829d7fe3929d",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[38731, 1106, 171, 3, 100, "Section",ExpressionUUID->"d660501a-fd8a-4ce2-854e-6fcbd443b279"],
Cell[38905, 1111, 583, 14, 86, "Text",ExpressionUUID->"200069e8-5608-4534-8105-e11b512c80ad"],
Cell[39491, 1127, 300, 6, 67, "MathCaption",ExpressionUUID->"612fbb8e-a4a0-4a29-8937-0192cac0b501"],
Cell[39794, 1135, 885, 19, 43, "Input",ExpressionUUID->"f6a29985-d2bf-46b9-99fe-69fd3f1784c5"],
Cell[40682, 1156, 73, 0, 20, "Spacer",ExpressionUUID->"880546ac-3d0a-4bc0-a092-872500ffd762"],
Cell[40758, 1158, 311, 6, 82, "Text",ExpressionUUID->"19477078-8fa4-4b80-8ef6-e04ef69d8591"],
Cell[41072, 1166, 133, 0, 67, "MathCaption",ExpressionUUID->"0dde4428-a9d1-4052-8466-6229774566f6"],
Cell[41208, 1168, 313, 6, 43, "Input",ExpressionUUID->"be46d472-7e6d-42c3-9844-4d4df68f85b5"],
Cell[41524, 1176, 73, 0, 20, "Spacer",ExpressionUUID->"01e351e2-b27e-4036-bbc2-e01a97dcaf4d"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[41646, 1182, 122, 2, 1, "SlideShowNavigationBar",ExpressionUUID->"328e184d-66bb-41fa-842b-2820f6414c3e",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[41793, 1188, 243, 6, 55, "Section",ExpressionUUID->"4b494513-2c38-4079-8a8a-dd7d71191be5"],
Cell[42039, 1196, 271, 4, 60, "Text",ExpressionUUID->"cac9f346-6b2c-4a4e-b178-61dcf63caa24"],
Cell[42313, 1202, 367, 10, 54, "MathCaption",ExpressionUUID->"338420dc-bfca-44be-9a7e-984c34fd24b3"],
Cell[42683, 1214, 499, 14, 37, "Input",ExpressionUUID->"f62d3c74-b95b-48dd-92b2-11d54f47d535"],
Cell[43185, 1230, 69, 0, 24, "MR",ExpressionUUID->"427f3635-cc2b-4e6e-8e26-15ea1aea71b8"],
Cell[43257, 1232, 437, 9, 88, "Text",ExpressionUUID->"0b010929-ddc9-46ec-aa9f-a0ba06adb30e"],
Cell[43697, 1243, 318, 8, 69, "MathCaption",ExpressionUUID->"4a7bbe00-e2b6-47c9-89d3-d19b4633ef07"],
Cell[44018, 1253, 718, 21, 43, "Input",ExpressionUUID->"c8cb522a-a2cb-4957-9dca-f8cb65095ddb"],
Cell[44739, 1276, 197, 3, 67, "MathCaption",ExpressionUUID->"3c923fd0-b010-4488-892d-6b98452dc696"],
Cell[44939, 1281, 234, 5, 43, "Input",ExpressionUUID->"57f2d68d-5dbc-4773-9922-8d3cce3b48d8"],
Cell[45176, 1288, 73, 0, 20, "Spacer",ExpressionUUID->"5337a8fb-6ef8-43d1-98a5-c881026c238d"],
Cell[45252, 1290, 208, 3, 79, "Text",ExpressionUUID->"8f16cd84-c848-4830-b444-610049fa9c71"],
Cell[45463, 1295, 163, 4, 69, "MathCaption",ExpressionUUID->"671f28e6-e8a2-43a5-9f72-2a1575b2cd97"],
Cell[45629, 1301, 844, 22, 73, "Input",ExpressionUUID->"6b256822-f367-4f3f-bf2c-d00e4c91a5c9"],
Cell[46476, 1325, 69, 0, 24, "MR",ExpressionUUID->"11f34f7d-c4bf-450f-865c-62e87587aaeb"],
Cell[46548, 1327, 539, 9, 110, "Text",ExpressionUUID->"4ebbc8d9-3661-4c5a-9a1b-098355044f40"],
Cell[47090, 1338, 244, 6, 67, "MathCaption",ExpressionUUID->"d3abc553-bf37-442c-9833-5140cd78dc5d"],
Cell[47337, 1346, 222, 4, 43, "Input",ExpressionUUID->"0c9fa548-49eb-42e3-ac35-d052e85883fa"],
Cell[47562, 1352, 73, 0, 20, "Spacer",ExpressionUUID->"f4d013fc-bb06-4a5b-9e17-121242739af6"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[47684, 1358, 122, 2, 1, "SlideShowNavigationBar",ExpressionUUID->"5a3339e5-e2b5-4d72-819c-dcd9f8812df8",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[47831, 1364, 107, 0, 100, "Section",ExpressionUUID->"d5c119f7-337f-4c23-895c-22c7219d768f"],
Cell[47941, 1366, 1055, 26, 117, "Text",ExpressionUUID->"9a4ba124-a377-4664-bfd2-55657fbcf14c"],
Cell[48999, 1394, 120, 0, 67, "MathCaption",ExpressionUUID->"c914c148-fb91-4cc3-949f-2e58e132ff70"],
Cell[49122, 1396, 203, 4, 43, "Input",ExpressionUUID->"e6e54fbe-b3b5-4f32-9b71-dd4de441a79c"],
Cell[49328, 1402, 425, 12, 74, "MathCaption",ExpressionUUID->"6836e6d2-4cc9-4ad5-bee8-756c76aed3ea"],
Cell[49756, 1416, 199, 4, 43, "Input",ExpressionUUID->"6eadb6e8-fcb3-4126-92c0-e0256bcc1b32"],
Cell[49958, 1422, 149, 2, 67, "MathCaption",ExpressionUUID->"39695bc0-631e-4fc0-a694-43730492a2a0"],
Cell[50110, 1426, 254, 7, 43, "Input",ExpressionUUID->"9309984a-5268-4126-87c5-fefc5e736696"],
Cell[50367, 1435, 69, 0, 24, "MR",ExpressionUUID->"d7fb671e-3aca-45a6-9121-ac0095ee92ee"],
Cell[50439, 1437, 153, 2, 48, "Text",ExpressionUUID->"62563056-432b-4d8a-b40b-f84fe9677c94"],
Cell[50595, 1441, 229, 3, 98, "MathCaption",ExpressionUUID->"67f2f6df-d92c-4eb8-a6fa-cbfbb3f0fe2c"],
Cell[50827, 1446, 418, 11, 43, "Input",ExpressionUUID->"c5e3f497-a6fc-4f54-8a45-c0c83b110276"],
Cell[51248, 1459, 408, 11, 74, "MathCaption",ExpressionUUID->"5c9a0bab-aaee-4721-9a0c-e6631ea7b9f7"],
Cell[51659, 1472, 428, 11, 43, "Input",ExpressionUUID->"f57b14cb-4306-4d4a-af40-5d22bd3622a8"],
Cell[52090, 1485, 132, 1, 43, "Input",ExpressionUUID->"33a22da7-da08-41d5-b1d7-388ff52d39dc"],
Cell[52225, 1488, 73, 0, 20, "Spacer",ExpressionUUID->"12883c87-c7dc-48a0-a6d1-f34adac0b91c"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[52347, 1494, 122, 2, 1, "SlideShowNavigationBar",ExpressionUUID->"592ec17c-dfd2-4405-b64d-f747750d2a30",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[52494, 1500, 119, 2, 100, "Section",ExpressionUUID->"d2f6bb35-6f9d-4644-92ba-108b5946139d",
 InitializationGroup->True],
Cell[CellGroupData[{
Cell[52638, 1506, 96, 0, 58, "MoreExamplesSection",ExpressionUUID->"f9d8b752-280d-423d-9bb6-fa41eb1cb070"],
Cell[52737, 1508, 485, 12, 70, "Input",ExpressionUUID->"59377da9-a95a-41ae-9486-b8b81c94df75"]
}, Closed]],
Cell[CellGroupData[{
Cell[53259, 1525, 174, 3, 50, "MoreExamplesSection",ExpressionUUID->"d7153357-120d-4d53-b003-315473acd215"],
Cell[53436, 1530, 262, 6, 70, "Input",ExpressionUUID->"09611e8d-9e7d-4597-96a5-bb272fc3d27c"],
Cell[53701, 1538, 3857, 88, 70, "Input",ExpressionUUID->"8cd0a36f-40c4-4757-b872-08aac82be56a"],
Cell[57561, 1628, 2441, 48, 70, "Input",ExpressionUUID->"bb871b44-c009-4883-bb3a-9230d31937bb"],
Cell[60005, 1678, 2690, 63, 70, "Input",ExpressionUUID->"406d20e9-6f97-49e2-acf9-a2f61d6920bb"],
Cell[62698, 1743, 1033, 24, 70, "Input",ExpressionUUID->"fd4e0882-5fe1-4a8c-aa06-57e57e867c65"]
}, Closed]],
Cell[CellGroupData[{
Cell[63768, 1772, 100, 0, 50, "MoreExamplesSection",ExpressionUUID->"755eb2ad-41cb-45a4-a861-0df09a5252c1"],
Cell[63871, 1774, 1655, 48, 70, "Input",ExpressionUUID->"14bfced7-13df-4601-909c-9c7882dbf198"]
}, Closed]],
Cell[CellGroupData[{
Cell[65563, 1827, 149, 3, 50, "MoreExamplesSection",ExpressionUUID->"10d39ad1-adf4-409d-a84d-f3da55140109"],
Cell[65715, 1832, 363, 9, 70, "Input",ExpressionUUID->"10f4edc4-ea6b-4401-9fea-e942ae1557b4"],
Cell[66081, 1843, 264, 6, 70, "Input",ExpressionUUID->"03ef0326-ec8d-43f5-aead-e1699c3966f8"],
Cell[66348, 1851, 261, 6, 70, "Input",ExpressionUUID->"b02131b9-62b6-43a8-a70b-1cf9be85d018"]
}, Closed]],
Cell[CellGroupData[{
Cell[66646, 1862, 170, 3, 50, "MoreExamplesSection",ExpressionUUID->"37ba1e73-9212-484c-9920-1cfd6cc510e5"],
Cell[66819, 1867, 145, 2, 70, "Input",ExpressionUUID->"77bef564-b93a-4dce-9911-300ff20a23f4"],
Cell[66967, 1871, 126, 1, 70, "Input",ExpressionUUID->"663eb5d1-88ad-4aa6-91a5-1dc555ff3744"]
}, Closed]],
Cell[CellGroupData[{
Cell[67130, 1877, 178, 3, 50, "MoreExamplesSection",ExpressionUUID->"9aef5ff7-a0ce-4dc4-9093-be43d0d97029"],
Cell[67311, 1882, 267, 7, 70, "Input",ExpressionUUID->"2e24f237-4974-4e99-a0b7-41a34682593f"]
}, Closed]],
Cell[CellGroupData[{
Cell[67615, 1894, 92, 0, 50, "MoreExamplesSection",ExpressionUUID->"35317706-9a76-4df4-a8b1-86df5f9d1416"],
Cell[67710, 1896, 126, 2, 70, "Input",ExpressionUUID->"0ff49f10-cdf1-4107-87b2-bfd8c3ab048f"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)

